* ====================== Program: PDI_ALL_MEASURES.SAS ======================;
*
*  Description:
*         ASSIGNS THE PEDIATRIC OUTCOME OF INTEREST INDICATORS TO INPATIENT RECORDS. 
*         VARIABLES CREATED BY THIS PROGRAM ARE TPPDxx, TAPDxx, GPPxx, AND STRATIFIERS;
*
*                >>> AHRQ QI ICD-10 VERSION 6.0.1 <<<
*		           >>> VERSION DATE SEPT, 2016 <<<
*
*  USER NOTE1: The PDI_ALL_FORMATS.SAS program must be run BEFORE
*               running this program.

*  USER NOTE2: The AHRQ QI software does not support the calculation of  
*              weighted estimates and standard errors using complex 
*              sampling designs. 
* ============================================================================;

*PATHNAME specifies the location of the PDI folder which includes 
          Programs, SASdata, and Macros subfolders;
%LET PATHNAME=c:\pathname;                        *<==USER MUST modify;

filename CONTROL "&PATHNAME.\PDI\Programs\PDI_ALL_CONTROL.SAS"; 

%INCLUDE CONTROL;

 title2 'PDI Measures';
 title3 'AHRQ PEDIATRIC QUALITY INDICATORS: ASSIGN PDIS TO INPATIENT DATA';

 * ------------------------------------------------------------------ ;
 * --- CREATE A PERMANENT DATASET CONTAINING ALL RECORDS THAT     --- ; 
 * --- WILL NOT BE INCLUDED IN ANALYSIS BECAUSE KEY VARIABLE      --- ;
 * --- VALUES ARE MISSING. REVIEW AFTER RUNNING PDI_ALL_MEASURES. --- ;
 * ------------------------------------------------------------------ ;

 data   OUTMSR.&DELFILE.
 	(keep=KEY HOSPID SEX AGE DX1 MDC YEAR DQTR);
 set 	INMSR.&DISCHARGE.;
 if (AGE lt 0) or (AGE ge 18 or MDC in (14)) or (SEX le 0) or 
	(DX1 in (' ')) or (DQTR le .Z) or (YEAR le .Z);
 run;
 
  *--- Load standard diagnosis and procedure macros ---* ;
 %include Maclib(PDI_Dx_Px_Macros.sas) ;

 * -------------------------------------------------------------- ;
 * --- PEDIATRIC QUALITY INDICATOR (PDI) NAMING CONVENTION:   --- ;
 * --- THE FIRST LETTER IDENTIFIES THE PEDIATRIC INDICATOR    --- ;
 * --- AS ONE OF THE FOLLOWING:
                (T) NUMERATOR ("TOP")
                (Q) PRESENT ON ADMISSION (POA)
                (G) MEASURE SPECIFIC STRATIFICATION ("GROUP")
 * --- THE SECOND LETTER IDENTIFIES THE PDI AS A PROVIDER (P) --- ;
 * --- OR AN AREA (A) LEVEL INDICATOR.  THE NEXT TWO          --- ;
 * --- CHARACTERS ARE 'PD' OR 'NQ'. THE LAST TWO DIGITS ARE    --- ;
 * --- THE INDICATOR NUMBER (WITHIN THAT SUBTYPE).            --- ;
 * -------------------------------------------------------------- ;

data   OUTMSR.&OUTFILE_MEAS.
    (keep=KEY HOSPID FIPST FIPSTCO DRG MDC MDRG YEAR DQTR AGE SEX
          PAGECAT AGEDCAT POPCAT BWHTCAT SEXCAT CONGCAT RACECAT PAYCAT DUALCAT
          LOS TRNSFER MAXPR NOPOUB04 NOPRDAY TRNSOUT  
          TPPD01--TPPD13 TPPS17 QPPD01--QPPD13  
          TPNQ01--TPNQ03 QPNQ01--QPNQ03 
          TAPD14--TAPD18 TAPD90--TAPD92 TAPQ09 
          GPPD01 GPPD02 GPPD08 GPPD10 GPPD11 GPPD12);

 set   INMSR.&DISCHARGE. 
      (keep=KEY HOSPID DRG MDC SEX AGE AGEDAY PSTCO 
            RACE YEAR DQTR PAY1 PAY2 DISP LOS ASOURCE POINTOFORIGINUB04 ATYPE
            DX1-DX&NDX. PR1-PR&NPR. %ADDPRDAY 
            DXPOA1-DXPOA&NDX. );

 * -------------------------------------------------------------- ;
 * --- DEFINE MDC                        ------------------------ ;
 * -------------------------------------------------------------- ;
 attrib MDCNEW length=3
   label='IMPUTED MDC';

 if MDC notin (01,02,03,04,05,06,07,08,09,10,
               11,12,13,14,15,16,17,18,19,20,
               21,22,23,24,25)
 then do;
    MDCNEW = put(DRG,MDCF2T.);
    if MDCNEW in (01,02,03,04,05,06,07,08,09,10,
                  11,12,13,14,15,16,17,18,19,20,
                  21,22,23,24,25)
    then MDC=MDCNEW;
    else do;
       if DRG in (999) then MDC = 0;
       else put "INVALID MDC KEY: " KEY " MDC " MDC " DRG " DRG ;
    end;
 end;
 

 * -------------------------------------------------------------- ;
 * --- DELETE NON-PEDIATRIC RECORDS AND RECORDS W MISSING VALUES  ;
 * -------------------------------------------------------------- ;
 if SEX le 0 then delete;
 if AGE lt 0 then delete;
 if AGE ge 18 or MDC in (14) then delete;
 if DX1 in (' ') then delete;
 if DQTR le .Z then delete;
 if YEAR le .Z then delete;


 * -------------------------------------------------------------- ;
 * --- COUNT THE NUMBER OF PR CODES                     --------- ;
 * -------------------------------------------------------------- ;
 array ARRY3{&NPR.} PR1-PR&NPR.;
 array ARRY6{&NPR.} PRDAY1-PRDAY&NPR.;

 MAXPR = 0; CNTPRDAY = 0;
 do I = 1 to &NPR.;
    if ARRY3(I) notin (' ') then MAXPR + 1;
    if ARRY6(I) ge 0 then CNTPRDAY + 1;
 end;

 if &PRDAY. EQ 0 or CNTPRDAY = 0 then NOPRDAY = 1;
 else NOPRDAY = 0;

 * -------------------------------------------------------------- ;
 * --- DEFINE FIPS STATE AND COUNTY CODES             ----------- ;
 * -------------------------------------------------------------- ;
 attrib FIPSTCO length=$5
   label='FIPS STATE COUNTY CODE';
 FIPSTCO = put(PSTCO,Z5.);

 attrib FIPST length=$2
   label='STATE FIPS CODE';
 FIPST = SUBSTR(FIPSTCO,1,2);


 * -------------------------------------------------------------- ;
 * --- DEFINE ICD-10-CM VERSION          ------------------------ ;
 * -------------------------------------------------------------- ;
 attrib ICDVER length=3
   label='ICD-10-CM VERSION';

 ICDVER = 0;
 if (YEAR in (2015) and DQTR in (4))     then ICDVER = 33;
 else if (YEAR in (2016) and DQTR in (1,2,3)) then ICDVER = 33;
 else ICDVER=33;

 * -------------------------------------------------------------- ;
 * --- DEFINE MEDICAL DRGS               ------------------------ ;
 * -------------------------------------------------------------- ;
 attrib MEDICDR length=3
   label='MEDICAL DRGS';

 if %MDR($MEDIC2R.) then MEDICDR = 1;
 else MEDICDR = 0;


 * -------------------------------------------------------------- ;
 * --- DEFINE SURGICAL DRGS              ------------------------ ;
 * -------------------------------------------------------------- ;
 attrib SURGIDR length=3
   label='SURGICAL DRGS';

 if %MDR($SURGI2R.) then SURGIDR = 1;
 else SURGIDR = 0;


 * -------------------------------------------------------------- ;
 * --- DEFINE MODIFIED DRGS              ------------------------ ;
 * -------------------------------------------------------------- ;
 attrib MDRG length=4
   label='MODIFIED DRG';

MDRG = put(put(DRG,Z3.),$DRGF2T.);

 * -------------------------------------------------------------- ;
 * --- DEFINE INFECTION RISK CATEGORIES  ------------------------ ;
 * -------------------------------------------------------------- ;
 attrib DRG1C length=3
   label='CLEAN';
 attrib DRG2C length=3
   label='CLEAN CONTAMINATED';
 attrib DRG3C length=3
   label='POTENTIALLY CONTAMINATED';
 attrib DRG4C length=3
   label='LIKELY INFECTED';
 attrib DRG9C length=3
   label='SURGICAL PROCEDURES NOT SPECIFIED';

 DRG1C = put(MDRG,DRG1C.);
 DRG2C = put(MDRG,DRG2C.);
 DRG3C = put(MDRG,DRG3C.);
 DRG4C = put(MDRG,DRG4C.);
 DRG9C = put(MDRG,DRG9C.);


 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: PAYER CATEGORY ------------------------ ;
 * -------------------------------------------------------------- ;
 attrib PAYCAT length=3
   label='PATIENT PRIMARY PAYER';

 select (PAY1);
   when (1)  PAYCAT = 1;
   when (2)  PAYCAT = 2;
   when (3)  PAYCAT = 3;
   when (4)  PAYCAT = 4;
   when (5)  PAYCAT = 5;
   otherwise PAYCAT = 6;
 end; 

 attrib DUALCAT length=3
   label='PATIENT DUAL ELIGIBLE';

 if (PAY1 in (1) and PAY2 in (2)) or
    (PAY1 in (2) and PAY2 in (1)) 
 then DUALCAT = 1; else DUALCAT = 0;
    

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: RACE CATEGORY ------------------------- ;
 * -------------------------------------------------------------- ;
 attrib RACECAT length=3
   label='PATIENT RACE/ETHNICITY';

 select (RACE);
   when (1)  RACECAT = 1;
   when (2)  RACECAT = 2;
   when (3)  RACECAT = 3;
   when (4)  RACECAT = 4;
   when (5)  RACECAT = 5;
   otherwise RACECAT = 6;
 end; 


 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: AGE CATEGORY  ------------------------- ;
 * -------------------------------------------------------------- ;
 attrib PAGECAT length=3
   label='PATIENT AGE';

 select;
   when (0  <= AGE <  1)  PAGECAT = 1;
   when (1  <= AGE <  3)  PAGECAT = 2;
   when (3  <= AGE <  6)  PAGECAT = 3;
   when (6  <= AGE < 13)  PAGECAT = 4;
   when (13 <= AGE < 18)  PAGECAT = 5;
   otherwise PAGECAT = 0;
 end; 


 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: AGEDAY CATEGORY  ---------------------- ;
 * -------------------------------------------------------------- ;
 attrib AGEDCAT length=3
   label='PATIENT AGE IN DAYS';

 select;
   when (      AGEDAY <   0)  AGEDCAT = 0;
   when (0  <= AGEDAY <= 28)  AGEDCAT = 1;
   when (29 <= AGEDAY <= 60)  AGEDCAT = 2;
   when (61 <= AGEDAY <= 90)  AGEDCAT = 3;
   when (91 <= AGEDAY      )  AGEDCAT = 4;
   otherwise AGEDCAT = 0;
 end; 


 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: SEX CATEGORY  ------------------------- ;
 * -------------------------------------------------------------- ;
 attrib SEXCAT length=3
   label='PATIENT SEX';

 select (SEX);
   when (1)  SEXCAT = 1;
   when (2)  SEXCAT = 2;
   otherwise SEXCAT = 0;
 end;


 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: POPULATION CATEGORY ------------------- ;
 * -------------------------------------------------------------- ;
 attrib POPCAT length=3
   label='PATIENT AGE';

 POPCAT=put(AGE,AGEFMT.);


 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: BIRTH WEIGHT CATEGORY  ---------------- ;
 * -------------------------------------------------------------- ;
 attrib BWHTCAT length=3
   label='PATIENT BIRTHWEIGHT';

 %MACRO BWHT;

 BWHTCAT = 0;
 %DO I = 1 %TO &NDX.;
    if put(DX&I.,$LW500G.)  = '1'      then BWHTCAT = 1;
    else if put(DX&I.,$LW750G.)  = '1' and (BWHTCAT = 0 or  BWHTCAT > 2) then BWHTCAT = 2;
    else if put(DX&I.,$LW1000G.) = '1' and (BWHTCAT = 0 or  BWHTCAT > 3) then BWHTCAT = 3;
    else if put(DX&I.,$LW1250G.) = '1' and (BWHTCAT = 0 or  BWHTCAT > 4) then BWHTCAT = 4;
    else if put(DX&I.,$LW1500G.) = '1' and (BWHTCAT = 0 or  BWHTCAT > 5) then BWHTCAT = 5;
    else if put(DX&I.,$LW1750G.) = '1' and (BWHTCAT = 0 or  BWHTCAT > 6) then BWHTCAT = 6;
    else if put(DX&I.,$LW2000G.) = '1' and (BWHTCAT = 0 or  BWHTCAT > 7) then BWHTCAT = 7;
    else if put(DX&I.,$LW2500G.) = '1' and (BWHTCAT = 0 or  BWHTCAT > 8) then BWHTCAT = 8;
 %END;
 
 %MEND;

 %BWHT;


 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: GESTATIONAL AGE CATEGORY -------------- ;
 * -------------------------------------------------------------- ;
 attrib GESTCAT length=3
   label='PATIENT GESTATIONAL AGE';

 %MACRO GEST;

 GESTCAT = 0;
 %DO I = 1 %TO &NDX.;
    if put(DX&I.,$GESTC1D.)  = '1'     then GESTCAT = 1;
    else if put(DX&I.,$GESTC2D.) = '1' and (GESTCAT = 0 or GESTCAT > 2) then GESTCAT = 2;
    else if put(DX&I.,$GESTC3D.) = '1' and (GESTCAT = 0 or GESTCAT > 3) then GESTCAT = 3;
    else if put(DX&I.,$GESTC4D.) = '1' and (GESTCAT = 0 or GESTCAT > 4) then GESTCAT = 4;
    else if put(DX&I.,$GESTC5D.) = '1' and (GESTCAT = 0 or GESTCAT > 5) then GESTCAT = 5;
    else if put(DX&I.,$GESTC6D.) = '1' and (GESTCAT = 0 or GESTCAT > 6) then GESTCAT = 6;
    else if put(DX&I.,$GESTC7D.) = '1' and (GESTCAT = 0 or GESTCAT > 7) then GESTCAT = 7;
    else if put(DX&I.,$GESTC8D.) = '1' and (GESTCAT = 0 or GESTCAT > 8) then GESTCAT = 8;
 %END;
 
 %MEND;

 %GEST;


 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: CONGENITAL ANAMOLY     ---------------- ;
 * -------------------------------------------------------------- ;
 attrib CONGCAT length=3
   label='CONGENITAL ANAMOLY';

%MACRO CONG;
CONGCAT = 0;
%DO I = 1 %TO &NDX.;
    if put(DX&I.,$CONGN1D.)  = '1'     then CONGCAT = 1;
    else if put(DX&I.,$CONGN2D.) = '1' and (CONGCAT = 0 or CONGCAT > 2) then CONGCAT = 2;
    else if put(DX&I.,$CONGN3D.) = '1' and (CONGCAT = 0 or CONGCAT > 3) then CONGCAT = 3;
    else if put(DX&I.,$CONGN4D.) = '1' and (CONGCAT = 0 or CONGCAT > 4) then CONGCAT = 4;
    else if put(DX&I.,$CONGN5D.) = '1' and (CONGCAT = 0 or CONGCAT > 5) then CONGCAT = 5;
    else if put(DX&I.,$CONGN6D.) = '1' and (CONGCAT = 0 or CONGCAT > 6) then CONGCAT = 6;
    else if put(DX&I.,$CONGN7D.) = '1' and (CONGCAT = 0 or CONGCAT > 7) then CONGCAT = 7;
    else if put(DX&I.,$CONGN8D.) = '1' and (CONGCAT = 0) then CONGCAT = 8;
%END;

%MEND;

%CONG;

 * -------------------------------------------------------------- ;
 * --- COUNT OR PROCEDURES AND IDENTIFY FIRST OR PROCEDURE ------ ;
 * -------------------------------------------------------------- ;
 attrib ORCNT length=8
   label='OR PROCEDURE COUNT';

 attrib ORDAY length=8
   label='OR PROCEDURE DAY';

 %ORCNT;


 * -------------------------------------------------------------- ;
 * --- DEFINE PROVIDER LEVEL INDICATORS ------------------------- ;
 * -------------------------------------------------------------- ;

 %MACRO LBL;

 attrib
 TPPD01 length=8
   label='PDI 01 Accidental Puncture or Laceration Rate (Numerator)'
 TPPD02 length=8
   label='PDI 02 Pressure Ulcer Rate (Numerator)'
 TPPD03 length=8
   label='PDI 03 Retained Surgical Item or Unretrieved Device Fragment Count (Numerator)'
 TPPD05 length=8
   label='PDI 05 Iatrogenic Pneumothorax Rate (Numerator)'
 TPPD06 length=8
   label='PDI 06 RACHS-1 Pediatric Heart Surgery Mortality Rate (Numerator) - Measure not calculated in AHRQ QI v6.0 software'
 TPPD07 length=8
   label='PDI 07 RACHS-1 Pediatric Heart Surgery Volume (Numerator) - Measure not calculated in AHRQ QI v6.0 software'
 TPPD08 length=8
   label='PDI 08 Perioperative Hemorrhage or Hematoma Rate (Numerator)'
 TPPD09 length=8
   label='PDI 09 Postoperative Respiratory Failure Rate (Numerator)'
 TPPD10 length=8
   label='PDI 10 Postoperative Sepsis Rate (Numerator)' 
 TPPD11 length=8
   label='PDI 11 Postoperative Wound Dehiscence Rate (Numerator)'
 TPPD12 length=8
   label='PDI 12 Central Venous Catheter-Related Blood Stream Infection Rate (Numerator)'
 TPPD13 length=8
   label='PDI 13 Transfusion Reaction Count (Numerator)'
 TPPS17 length=8
   label='PSI 17 Birth Trauma Rate  Injury to Neonate (Numerator)'
;

 attrib
 TPNQ01 length=8
   label='NQI 01 Neonatal Iatrogenic Pneumothorax Rate (Numerator)'
 TPNQ02 length=8
   label='NQI 02 Neonatal Mortality Rate (Numerator)'
 TPNQ03 length=8
   label='NQI 03 Neonatal Blood Stream Infection Rate (Numerator)'
;

 attrib
 QPPD01 length=3
   label='PDI 01 Accidental Puncture or Laceration Rate (POA)'
 QPPD02 length=3
   label='PDI 02 Pressure Ulcer Rate (POA)'
 QPPD03 length=3
   label='PDI 03 Retained Surgical Item or Unretrieved Device Fragment Count (POA)'
 QPPD05 length=3
   label='PDI 05 Iatrogenic Pneumothorax Rate (POA)'
 QPPD08 length=3
   label='PDI 08 Perioperative Hemorrhage or Hematoma Rate (POA)'
 QPPD09 length=3
   label='PDI 09 Postoperative Respiratory Failure Rate (POA)'
 QPPD10 length=3
   label='PDI 10 Postoperative Sepsis Rate (POA)' 
 QPPD11 length=3
   label='PDI 11 Postoperative Wound Dehiscence Rate (POA)'
 QPPD12 length=3
   label='PDI 12 Central Venous Catheter-Related Blood Stream Infection Rate (POA)'
 QPPD13 length=3
   label='PDI 13 Transfusion Reaction Count (POA)'
;

 attrib
 QPNQ01 length=3
   label='NQI 01 Neonatal Iatrogenic Pneumothorax Rate (POA)'
 QPNQ03 length=3
   label='NQI 03 Neonatal Blood Stream Infection Rate (POA)'
;

 * -------------------------------------------------------------- ;
 * --- DEFINE AREA LEVEL INDICATORS ----------------------------- ;
 * -------------------------------------------------------------- ;
 attrib
 TAPD14 length=8
   label='PDI 14 Asthma Admission Rate (Numerator)'
 TAPD15 length=8
   label='PDI 15 Diabetes Short-Term Complications Admission Rate (Numerator)'
 TAPD16 length=8
   label='PDI 16 Gastroenteritis Admission Rate (Numerator)'
 TAPD17 length=8
   label='PDI 17 Perforated Appendix Admission Rate (Numerator)'
 TAPD18 length=8
   label='PDI 18 Urinary Tract Infection Admission Rate (Numerator)'
 TAPD90 length=8
   label='PDI 90 Pediatric Quality Overall Composite (Numerator)'
 TAPD91 length=8
   label='PDI 91 Pediatric Quality Acute Composite (Numerator)'
 TAPD92 length=8
   label='PDI 92 Pediatric Quality Chronic Composite (Numerator)'
 TAPQ09 length=8
   label='PQI 09 Low Birth Weight Rate (Numerator)'
;

 * -------------------------------------------------------------- ;
 * --- RE-LABEL DAY DEPENDENT INDICATORS ------------------------ ;
 * -------------------------------------------------------------- ;
 %IF &PRDAY. = 0 %THEN %DO;

 label
   TPPD02 = 'PDI 02 Pressure Ulcer Rate-NO PRDAY (Numerator)'
   TPPD08 = 'PDI 08 Perioperative Hemorrhage or Hematoma Rate-NO PRDAY (Numerator)'
   TPPD09 = 'PDI 09 Postoperative Respiratory Failure Rate-NO PRDAY (Numerator)'
   TPPD11 = 'PDI 11 Postoperative Wound Dehiscence Rate-NO PRDAY (Numerator)'
 ;
 %END;

 %MEND;

 %LBL;

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIERS                  ---------------------- ;
 * -------------------------------------------------------------- ;
  attrib
  GPPD01 length=3
   label='STRATA FOR PDI 01'
  GPPD02 length=3
   label='STRATA FOR PDI 02'
  GPPD08 length=3
   label='STRATA FOR PDI 08'
  GPPD10 length=3
   label='STRATA FOR PDI 10'
  GPPD11 length=3
   label='STRATA FOR PDI 11'
  GPPD12 length=3
   label='STRATA FOR PDI 12'
 ;

 * -------------------------------------------------------------- ;
 * --- IDENTIFY NEONATES AND NEWBORNS --------------------------- ;
 * -------------------------------------------------------------- ;

   NEONATE = 0;
   if 0 <= AGEDAY <= 28 then NEONATE = 1;
   else if AGEDAY le .Z and AGE = 0 then do;
      if ATYPE in (4) or %MDX($LIVEBND.)
      then NEONATE = 1;
   end;

   NEWBORN = 0;
   if NEONATE then do;
      if %MDX($LIVEBND.) and NOT AGEDAY > 0 then NEWBORN = 1;
      else if ATYPE in (4) and 
              ((AGEDAY = 0 and NOT %MDX($LIVEB2D.)) or
               POINTOFORIGINUB04 in ('5'))
      then NEWBORN = 1;
   end;
 
   NORMAL = 0;
   if NEWBORN and (DRG in (795))
   then NORMAL = 1;

   OUTBORN = 0;
   if NEONATE and NOT NEWBORN then do;
      if (0 <= AGEDAY < 2) or 
         (ATYPE in (4) and 
          (AGEDAY le .Z or POINTOFORIGINUB04 in ('6'))) 
      then OUTBORN = 1;
   end;


 * --- CONSTRUCT PROVIDER LEVEL INDICATORS ---------------------- ;

 * -------------------------------------------------------------- ;
 * --- PDI 01 : ACCIDENTAL PUNCTURE OR LACERATION             --- ;
 * -------------------------------------------------------------- ;


   if MEDICDR or SURGIDR then do;

      TPPD01 = 0; QPPD01 = 0;

      if %MDX2($TECHNID.) then TPPD01 = 1;
      if %MDX2Q1($TECHNID.) then QPPD01 = 0;

      *** Exclude principal diagnosis; 

      if %MDX1($TECHNID.) then TPPD01 = .;
      if %MDX2Q2($TECHNID.) then QPPD01 = 1;

      *** Exclude spine surgery; 

      if %MPR($SPINEP.) then TPPD01 = .;

      *** Exclude Normal Newborn;

      if NORMAL then TPPD01 = .;

      *** Exclude Neonate < 500g;

      if NEONATE and BWHTCAT in (1) then TPPD01 = .;

      *** Set POA flag to missing;

      if TPPD01 = . then QPPD01 = .;
      if TPPD01 = 0 and QPPD01 = 1 then QPPD01 = 0;

	        *** Stratify by risk category (MDC)
           1 - Eye, ear, nose, mouth, throat, skin, breast and other low-risk procedures
           2 - Thoracic, cardiovascular, and specified neoplastic procedures
           3 - Kidney, and male/female reproductive procedures
           4 - Infectious, immunological, hematological, and ungroupable procedures
           5 - Trauma, orthopedic, and neurologic procedures
           6 - Gastrointestinal, hepatobiliary, and endocrine procedures;

      if TPPD01 NE . then do;
         if MDC in (2,3,9,19,22,23)     then GPPD01 = 1;
         else if MDC in (4,5,17)        then GPPD01 = 2; 
         else if MDC in (11,12,13)      then GPPD01 = 3; 
         else if MDC in (0,16,18,25,99) then GPPD01 = 4; 
         else if MDC in (1,8,21,24)     then GPPD01 = 5; 
         else if MDC in (6,7,10)        then GPPD01 = 6; 
         else GPPD01 = 9; 
      end;

    end;
 * -------------------------------------------------------------- ;
 * --- PDI 02 : PRESSURE ULCER                                --- ;
 * -------------------------------------------------------------- ;


 %MACRO PD2;

 if (&PRDAY. = 1  and ORDAY NE . and MPRDAY NE .) then do;

      if MPRDAY <= ORDAY then TPPD02 = .;

 end;
 else do;

      if %MPR1($DEBRIDP.) then TPPD02 = .;

 end;

 %MEND;

   if MEDICDR or SURGIDR then do;

	TPPD02 = 0; QPPD02 = 0;

	*** include if not in principal diagnosis;
	if %MDX2($DECUBVD.) then TPPD02 = 1;

	*** Exclude principal diagnosis; 
	if %MDX1($DECUBVD.) then TPPD02 = .;
	if %MDX2Q2($DECUBVD.) then QPPD02 = 1; /* at least one POA */
	if %MDX2Q1($DECUBVD.) then QPPD02 = 0; /* at least one not POA */
	
	if SURGIDR and ORCNT > 0 then do;
 
		*** Exclude if debridement or pedicle graft is the only OR procedure;
		%MPRCNT($DEBRIDP.);
		if ORCNT = MPRCNT then TPPD02 = .;

		*** Exclude if debridement or pedicle graft occurs before or 
		 on the same day as the first OR procedure;
		%ORDAY($DEBRIDP.);
		%MPRDAY($DEBRIDP.);
		%PD2;

	end;

      *** Exclude Major Skin Disorders ;
      if %MDXAQ2($PUXD.) or %MDXAQ2($EXFOLIATXD.) then TPPD02 = .;

	  *** Exclude LOS < 3, Transfer from Acute Care Facility or LTC;
      if LOS < 3 or 
         (ATYPE notin (4) AND
          (ASOURCE in (2,3) or
           POINTOFORIGINUB04 in ('4','5','6'))) 
      then TPPD02 = .;

      *** Exclude Neonate;
      if NEONATE then TPPD02 = .;

      *** Set POA flag to missing;
      if TPPD02 = . then QPPD02 = .;
      if TPPD02 = 0 and QPPD02 = 1 then QPPD02 = 0;

	        *** Stratify by risk category (1 - Low risk, 2 - High risk);
      if TPPD02 NE . then do;
         if %MDX($HEMIPID.) or %MDX($SPINABD.) or %MDX($ANOXBD.) or %MPR($CMVENP.) then GPPD02 = 2;
         else GPPD02 = 1; 
      end;

  end;


 * ----------------------------------------------------------------------- ;
 * --- PDI 03 : RETAINED SURGICAL ITEM OR UNRETRIEVED DEVICE FRAGMENT  --- ;
 * ----------------------------------------------------------------------- ;

   if (MEDICDR or SURGIDR) then do;

      TPPD03 = .; QPPD03 = 0;

      if %MDX2($FOREIID.) then TPPD03 = 1;
      if %MDX2Q1($FOREIID.) then QPPD03 = 0;

      *** Exclude principal diagnosis; 

      if %MDX1($FOREIID.) then TPPD03 = .;
      if %MDX2Q2($FOREIID.) then QPPD03 = 1;

      *** Exclude normal newborn; 

      if NORMAL then TPPD03 = .;

      *** Exclude Neonate < 500g;
      
      if NEONATE and BWHTCAT in (1) then TPPD03 = .;

      *** Set POA flag to missing;

      if TPPD03 = . then QPPD03 = .;
      if TPPD03 = 0 and QPPD03 = 1 then QPPD03 = 0;

   end;


 * ----------------------------------------------------------- ;
 * --- PDI 05 : IATROGENIC PNEUMOTHORAX                    --- ;
 * ----------------------------------------------------------- ;

   if MEDICDR or SURGIDR then do;

      TPPD05 = 0; QPPD05 = 0;
  
      if %MDX2($IATROID.) then TPPD05 = 1;
      if %MDX2Q1($IATROID.) then QPPD05 = 0;
           
      *** Exclude principal diagnosis; 

      if %MDX1($IATROID.) then TPPD05 = .;
      if %MDX2Q2($IATROID.) then QPPD05 = 1;

      *** Exclude Chest Trauma, Pleural effusion;

      if %MDX($CTRAUMD.) or %MDX($PLEURAD.) 
      then TPPD05 = .;

      *** Exclude Thoracic surgery, Lung or pleural biopsy,
          Cardiac surgery or Diaphragmatic surgery repair;

      if %MPR($THORAIP.) or %MPR($LUNGBIP.) or %MPR($CARDSIP.) or 
         %MPR($DIAPHRP.)
      then TPPD05 = .;

      *** Exclude normal newborn; 

      if NORMAL then TPPD05 = .;

      *** Exclude Neonate < 500g;
     
      if NEONATE and BWHTCAT in (1) then TPPD05 = .;

      if NEONATE = 1 and BWHTCAT in (2,3,4,5,6,7,8) then do;
         TPNQ01 = TPPD05;
         TPPD05 = .;
         QPNQ01 = QPPD05;
         QPPD05 = .;
      end;

      *** Set POA flag to missing;

      if TPPD05 = . then QPPD05 = .;
      if TPNQ01 = . then QPNQ01 = .;
      if TPPD05 = 0 and QPPD05 = 1 then QPPD05 = 0;
      if TPNQ01 = 0 and QPNQ01 = 1 then QPNQ01 = 0;

 end;


 * ------------------------------------------------------- ;
 * --- PDI 06 : PEDIATRIC HEART SURGERY MORTALITY      --- ;
 * ------------------------------------------------------- ;
   * --- Uses Risk Categories for Congenital Heart Surgery-1 (RACHS-1) --- ;
   * --- historical data that is unavailable in ICD-10.                --- ;
   * --- Disable PDI 06 until RACHS available                          --- ;
 TPPD06 = . ;
 
  * -------------------------------------------------- ;
  * --- PDI 07 : VOLUME PEDIATRIC HEART SURGERY    --- ;
  * -------------------------------------------------- ;
   * --- Uses Risk Categories for Congenital Heart Surgery-1 (RACHS-1) --- ;
   * --- historical data that is unavailable in ICD-10.                --- ;
   * --- Disable PDI 07 until RACHS available                          --- ;

 TPPD07 = . ;

  * ---------------------------------------------------------- ;
  * --- PDI 08 : POSTOPERATIVE HEMORRHAGE OR HEMATOMA      --- ;
  * ---------------------------------------------------------- ;

   %MACRO PD8;

   if (&PRDAY. = 1 and ORDAY NE . and MPRDAY NE .) then do;

      if (%MDX2($POHMRI2D.) and MPRDAY < ORDAY)
      then TPPD08 = .;

   end;
   else do;

      if (%MDX2($POHMRI2D.) and %MPR1($HEMOTH2P.))
      then TPPD08 = .;

   end;

   %MEND;

   

   if SURGIDR and ORCNT > 0 and ATYPE in (3) then do;

      TPPD08 = 0; QPPD08 = 0;

      if (%MDX2($POHMRI2D.) and %MPR($HEMOTH2P.))
      then TPPD08 = 1;

      if (%MDX2Q1($POHMRI2D.) and %MPR($HEMOTH2P.))   
      then QPPD08 = 0;

      *** Exclude principal diagnosis; 

      if %MDX1($POHMRI2D.) then TPPD08 = .;

      if %MDX2Q2($POHMRI2D.) then QPPD08 = 1;

      *** Exclude if control of post-operative hemorrhage or Miscellaneous Hemorrhage or
          hematoma-related procedure are the only OR procedures;

      %MPRCNT($HEMOTH2P.);

      if ORCNT = MPRCNT then TPPD08 = .;

      *** Exclude if control of post-operative hemorrhage or Miscellaneous Hemorrhage or
          hematoma-related procedure occurs before the first OR procedure;

      %ORDAY($HEMOTH2P.);
      %MPRDAY($HEMOTH2P.);
      %PD8;

      *** Exclude Neonate < 500g;
     
      if NEONATE and BWHTCAT in (1) then TPPD08 = .;


      *** Set POA flag to missing;

      if TPPD08 = . then QPPD08 = .;

      if TPPD08 = 0 and QPPD08 = 1 then QPPD08 = 0;

	        *** Stratify by risk category (1-Low risk, 2-High risk);

      if TPPD08 NE . then do;
         if %MDX($COAGDID.) or %MPR($ECMOP.) then GPPD08 = 2;
         else GPPD08 = 1;
      end;


     end;

      
   * ---------------------------------------------------------- ;
   * --- PDI 09 : POSTOPERATIVE RESPIRATORY FAILURE         --- ;
   * ---------------------------------------------------------- ;

   %MACRO PD9N(FMT,DAYS);

      %MPRDAY(&FMT.);

      if (&PRDAY. = 1  and ORDAY NE . and MPRDAY NE .) then do;

         if MPRDAY >= ORDAY + &DAYS. then TPPD09 = 1;

      end;
      else do;

         if %MPR2(&FMT.) then TPPD09 = 1;

      end;

   %MEND;

   %MACRO PD9;

      if (&PRDAY. = 1  and ORDAY NE . and MPRDAY NE .) then do;

         if MPRDAY < ORDAY then TPPD09 = .;

      end;
      else do;

         if %MPR1($TRACHIP.) then TPPD09 = .;

      end;

   %MEND;

   if SURGIDR and ORCNT > 0 and ATYPE in (3) then do;

      TPPD09 = 0; QPPD09 = 0;

      if %MDX2($ACURF2D.) then TPPD09 = 1;
      if %MDX2Q1($ACURF2D.) then QPPD09 = 0;

      *** Include in numerator if reintubation procedure occurs on the same day or
          # days after the first OR procedure;
 
      %ORDAY($BLANK.);
      %PD9N($PR9604P.,1);
      %PD9N($PR9671P.,2);
      %PD9N($PR9672P.,0);


	  *** Exclude principal diagnosis; 

      if %MDX1($ACURF3D.) then TPPD09 = .;
      if %MDX2Q2($ACURF3D.) then QPPD09 = 1;
 
      *** Exclude if tracheostomy procedure is the only OR procedure;

      %MPRCNT($TRACHIP.);
      if ORCNT = MPRCNT then TPPD09 = .;


      *** Exclude if tracheostomy procedure occurs before the 
          first OR procedure;

      %ORDAY($TRACHIP.);
      %MPRDAY($TRACHIP.);
      %PD9;

      *** Exclude Neuromuscular disorders;
 
      if %MDX($NEUROMD.) then TPPD09 = .;

      *** Exclude MDC 4, 5;
 
      if MDC in (4,5) then TPPD09 = .;

      *** Exclude Craniofacial anomalies;

      if %MPR($NUCRANP.) or
         (%MPR($NUCRANP.) and %MDX($CRANIID.))
      then TPPD09 = .;

      *** Exclude Neonate < 500g;
     
      if NEONATE and BWHTCAT in (1) then TPPD09 = .;

      *** Exclude Esophageal resection Procedure;

      if %MPR($PRESOPP.) or %MPR($PRESO2P.) 
      then TPPD09 = .;

      *** Exclude Lung Cancer Procedure;

      if %MPR($LUNGCIP.) then TPPD09 = .;

      *** Exclude diagnosis of Degenerative neurological disorder;

      if %MDX($DGNEUID.) then TPPD09 = .;

      *** Exclude Hospitalizations involving lung transplantations;
 
      if %MPR($LUNGTRANSP.) then TPPD09 = .;

      *** Set POA flag to missing;
      if TPPD09 = . then QPPD09 = .;
      if TPPD09 = 0 and QPPD09 = 1 then QPPD09 = 0;

	end;

 * ----------------------------------------- ;
 * --- PDI 10 : POSTOPERATIVE SEPSIS     --- ;
 * ----------------------------------------- ;

      if SURGIDR and ORCNT > 0 then do;

      TPPD10 = 0; QPPD10 = 0;

      if %MDX2($SEPTI2D.) then TPPD10 = 1;

      if %MDX2Q1($SEPTI2D.) then QPPD10 = 0;

      *** Exclude principal diagnosis; 

      if %MDX1($SEPTI2D.) then TPPD10 = .;

      if %MDX2Q2($SEPTI2D.) then QPPD10 = 1;


      *** Exclude Infection;

      if %MDX1($INFECID.) then TPPD10 = .;

      *** Exclude DRG in surgical class 4;

      if DRG4C then TPPD10 = .;
     
      *** Exclude Neonate;

      if NEONATE then TPPD10 = .;
 
      *** Set POA flag to missing;

      if TPPD10 = . then QPPD10 = .;
      if TPPD10 = 0 and QPPD10 = 1 then QPPD10 = 0;

	   *** Stratify by procedure type (1-Low risk to 4-High risk);

      if TPPD10 NE . then do;
         if DRG1C then do;
            if ATYPE in (3) then GPPD10 = 1; else GPPD10 = 2;
         end;
         else if DRG2C or DRG3C or DRG9C then do;
            if ATYPE in (3) then GPPD10 = 3; else GPPD10 = 4;
         end;
         else if DRG4C then GPPD10 = 5;
         else GPPD10 = 9;
      end;

   end;
 

 * ----------------------------------------------- ;
 * --- PDI 11 : POSTOPERATIVE WOUND DEHISCENCE --- ;
 * ----------------------------------------------- ;

   %MACRO PD11A;

      if (&PRDAY. = 1 and MPRDAYA NE . and MPRDAYB NE .) then do;

         if MPRDAYB <= MPRDAYA then TPPD11 = .;

      end ;
      else do;

         if %MPR1($RECLOIP.) then TPPD11 = .;

      end;

   %MEND;

   %MACRO PD11B;

      if (&PRDAY. = 1 and MPRDAYA NE . and MPRDAYB NE .) then do;

         if MPRDAYB < MPRDAYA then TPPD11 = .;

      end;
      else do;

         if %MPR1($REPGAST.) and %MDX($UMBHERND.) then TPPD11 = .;

      end;

   %MEND;

   if %MPR($ABDOMIP.) then do;

      TPPD11 = 0; QPPD11 = 0;

      if %MPR($RECLOIP.) and %MDX($ABWALLCD.) then TPPD11 = 1;

      *** Exclude if qualifying wound reclosure occurs before or on the same day as the first abdominopelvic procedure;

      MPRDAYA=.; MPRDAYB=.; 
      %MPRDAY($ABDOMIP.); MPRDAYA = MPRDAY;
      %MPRDAY($RECLOIP.); 
	  if MPRDAY > . and %MDX($ABWALLCD.) then MPRDAYB = MPRDAY;
      %PD11A;

      *** Exclude if gastrochiesis or umbilical hernia repair performed before reclosure;

      MPRDAYA=.; MPRDAYB=.; 
      %MPRDAY($RECLOIP.); 
      if MPRDAY > . and %MDX($ABWALLCD.) then MPRDAYA = MPRDAY;
      %MPRDAY($REPGAST.) ; 
      if MPRDAY > . AND %MDX($UMBHERND.) THEN MPRDAYB = MPRDAY;
      %PD11B;

      *** Exclude Primary Dx or secondary DX POA of Disruption of Internal Operation Wound -  V6.0 change;
      if %MDX1($ABWALLCD.) or %MDX2Q2($ABWALLCD.) then TPPD11 = .;

      *** Exclude High and Intermediate Risk Immunocompromised state;

      if %MDX($IMMUNHD.) or %MPR($TRANSPP.) then TPPD11 = .;     

      if %MDX($IMMUITD.) or (%MDX($HEPFA2D.) and %MDX($HEPFA3D.)) then TPPD11 = .; 

      *** Exclude LOS < 2; 
      if LOS < 2 then TPPD11 = .;

      *** Exclude Neonate < 500g;
     
      if NEONATE and BWHTCAT in (1) then TPPD11 = .;

      *** Set POA flag to missing;

      if TPPD11 = . then QPPD11 = .;
      if TPPD11 = 0 and QPPD11 = 1 then QPPD11 = 0;

	  *** Stratify by procedure type (1-Low risk to 4-High risk);

      if TPPD11 NE . then do;
         if DRG1C then do;
            if ATYPE in (3) then GPPD11 = 1; else GPPD11 = 2;
         end;
         else if DRG2C or DRG3C or DRG9C then do;
            if ATYPE in (3) then GPPD11 = 3; else GPPD11 = 4;
         end;
         else if DRG4C then GPPD11 = 5;
         else GPPD11 = 9;
      end;

   end;

 * --------------------------------------------------- ;
 * --- PDI 12 : CENTRAL VENOUS CATH RELATED BSI    --- ;
 * --------------------------------------------------- ;

   if MEDICDR or SURGIDR then do;

      TPPD12 = 0; QPPD12 = 0;

      if %MDX2($IDTMC3D.) then TPPD12 = 1;

	  if %MDX2Q1($IDTMC3D.) then QPPD12 = 0;

	   *** Exclude principal diagnosis; 

	  if %MDX1($IDTMC3D.) then TPPD12 = .;

	  if %MDX2Q2($IDTMC3D.) then QPPD12 = 1;


      *** Exclude LOS < 2;
 
      if LOS < 2 then TPPD12 = .;

      *** Exclude Newborn;

      if NORMAL then TPPD12 = .;

      *** Exclude Neonate < 500g;
     
      if NEONATE and BWHTCAT in (1) then TPPD12 = .;

      *** Set POA flag to missing;

      if TPPD12 = . then QPPD12 = .;
      if TPPD12 = 0 and QPPD12 = 1 then QPPD12 = 0;

	  *** Stratify by risk category (1-Low risk, 2-Intermediate risk, 3-High risk);

      if TPPD12 NE . then do;
         if %MDX($IMMUNHD.) or %MPR($TRANSPP.) or %MDX($CANITD.) then GPPD12 = 3;
         else if %MDX($IMMUITD.) or (%MDX($HEPFA2D.) and %MDX($HEPFA3D.)) or
                 %MDX($ACSCYFD.) or %MDX($HEMOPHD.) then GPPD12 = 2; 
         else GPPD12 = 1;
      end;

end;

 * --------------------------------------------- ;
 * --- PDI 13 : TRANSFUSION REACTION         --- ;
 * --------------------------------------------- ;

   if MEDICDR or SURGIDR then do;

      TPPD13 = .; QPPD13 = .;
 
      if %MDX2($TRANFID.) then TPPD13 = 1;
      if %MDX2Q1($TRANFID.) then QPPD13 = 0;

      *** Exclude principal diagnosis; 

      if %MDX1($TRANFID.) then TPPD13 = .;
      if %MDX2Q2($TRANFID.) then QPPD13 = 1;

      *** Exclude Neonate;

      if NEONATE then TPPD13 = .;

      *** Set POA flag to missing;

      if TPPD13 = . then QPPD13 = .;
      if TPPD13 = 0 and QPPD13 = 1 then QPPD13 = 0;

   end;

  

  * ------------------------------------------ ;
  * --- PSI 17 : BIRTH TRAUMA              --- ;
  * ------------------------------------------ ;

   if NEWBORN then do;

      TPPS17 = 0;

      if %MDX($BIRTHID.) then TPPS17 = 1;

   *** Exclude Birth weight less than 2000g;

      if %MDX($PRETEID.) then TPPS17 = .;
   *** Exclude Osteogenesis imperfecta;

      if %MDX($OSTEOID.) then TPPS17 = .;

   end;


 * ---  CONSTRUCT NEONATAL INDICATORS  --------- ;

  * ---------------------------------------- ;
  * --- NQI 02 : NEONATAL MORTALITY      --- ;
  * ---------------------------------------- ;

      if NEWBORN or OUTBORN then do;

         TPNQ02 = 0;

         if DISP in (20) then TPNQ02 = 1;

         *** Exclude trisomy 13, trisomy 18, anencephaly, 
             polycystic kidney ;
         if %MDX($NEOMTDX.) then TPNQ02 = .;

         *** Exclude birthweight < 500g;
         if BWHTCAT in (1) then TPNQ02 = .;

      end;


  * -------------------------------------------------- ;
  * --- NQI 03 : BLOOD STREAM INFECTION NEONATES   --- ;
  * -------------------------------------------------- ;

   if NEWBORN or OUTBORN then do;

      if BWHTCAT in (2,3,4,5)    or
         GESTCAT in (2,3,4,5)    or 
         (BWHTCAT in (0,6,7,8,9) and 
         (DISP in (20) or %MPR($ORPROC.) or %MPR($MECHVCD.) or
         ((0 <= AGEDAY < 2) and (ATYPE in (4) and POINTOFORIGINUB04 in ('6'))) 
         ))  
      then do;

         ORPROC = %MPR($ORPROC.);
         MECHVCD = %MPR($MECHVCD.);

         TPNQ03 = 0; QPNQ03 = 0;

         if (%MDX2($BSI2DX.) and %MDX2($BSI3DX.)) 
         then TPNQ03 = 1;

         if (%MDX2Q1($BSI2DX.) and %MDX2Q1($BSI3DX.)) 
         then QPNQ03 = 0;

         *** Exclude principal diagnosis of Sepsis; 

		 if %MDX1($SEPTI2D.) 
             or %MDX1($BSI3DX.) or %MDX1($BSI4DX.) then TPNQ03 = .;

		 if %MDX2Q2($SEPTI2D.)
             or %MDX2Q2($BSI3DX.) or %MDX2Q2($BSI4DX.) then QPNQ03 = 1;

         *** Exclude birthweight < 500g;
         if BWHTCAT in (1) then TPNQ03 = .;


		 *** Exclude LOS < 7;

		 if LOS < 7 then TPNQ03 = .;

         *** Set POA flag to missing;

         if TPNQ03 = . then QPNQ03 = .;


         if TPNQ03 = 0 and QPNQ03 = 1 then QPNQ03 = 0;

      end;

   end;
 * --- CONSTRUCT AREA LEVEL INDICATORS --- ;

 * -------------------------------------------------- ;
 * --- PDI 14 : PEDIATRIC ASTHMA                  --- ;
 * -------------------------------------------------- ;
   
   if %MDX1($ACSASTD.) then do;

      TAPD14 = 1;

      *** Exclude Cystic Fibrosis and Anomalies of the Respiratory System;

      if %MDX($RESPAN.) then TAPD14 = .;

      *** Exclude age < 2 years;

      if AGE < 2 then TAPD14 = .;

   end;


 * -------------------------------------------------- ;
 * --- PDI 15 : DIABETES SHORT TERM COMPLICATION  --- ;
 * -------------------------------------------------- ;

   if %MDX1($ACDIASD.) then do;

      TAPD15 = 1;

      *** Exclude age < 6 years;

      if AGE < 6 then TAPD15 = .;

   end;


 * -------------------------------------------------- ;
 * --- PDI 16 : PEDIATRIC GASTROENTERITIS         --- ;
 * -------------------------------------------------- ;

   if %MDX1($ACPGASD.) or (%MDX2($ACPGASD.) and %MDX1($ACSDEHD.)) then do;

      TAPD16 = 1;
  
      *** Exclude age <= 90 days;

      if 0 <= AGEDAY <= 90 or (AGEDAY < 0 and NEONATE) then TAPD16 = .;

     *** Exclude Gastrointestinal Abnormalities and Bacterial Gastroenteritis ;

     if %MDX($ACGDISD.) then TAPD16 = .; 
     if %MDX($ACBACGD.) then TAPD16 = .;
   
   end;


 * -------------------------------------------------- ;
 * --- PDI 17 : PERFORATED APPENDIX               --- ;
 * -------------------------------------------------- ;

   if %MDX($ACSAP2D.) then do;

      TAPD17 = 0;

      if %MDX($ACSAPPD.) then TAPD17 = 1;

      *** Exclude age < 1 year;

      if AGE < 1 then TAPD17 = .;

   end;


 * -------------------------------------------------- ;
 * --- PDI 18 : URINARY INFECTION                 --- ;
 * -------------------------------------------------- ;

   if %MDX1($ACSUTID.) then do;

      TAPD18 = 1;

      *** Exclude Kidney/Urinary Tract Disorder;

      if %MDX($KIDNEY.) then TAPD18 = .;

      *** Exclude High and Intermediate Risk Immunocompromised state;

      if %MDX($IMMUNHD.) or %MPR($TRANSPP.) then TAPD18 = .;     

      if %MDX($IMMUITD.) or (%MDX($HEPFA2D.) and %MDX($HEPFA3D.)) then TAPD18 = .; 

      *** Exclude age <= 90 days;

      if 0 <= AGEDAY <= 90 or (AGEDAY < 0 and NEONATE) then TAPD18 = .;
 
   end;

   * -------------------------------------------------- ;
   * --- PQI 09 : LOW BIRTH WEIGHT                  --- ;
   * -------------------------------------------------- ;

   if NEWBORN then do;

      TAPQ09 = 0;

      if %MDX($ACSLBWD.) then TAPQ09 = 1;

   end;

 * --- CONSTRUCT AREA LEVEL COMPOSITE INDICATORS ---------------- ;

   * ----------------------------------------------- ;
   * --- PDI 90 : OVERALL                        --- ;
   * ----------------------------------------------- ;

   if TAPD14 = 1 or TAPD15 = 1 or TAPD16 = 1 or TAPD18 = 1 then do;
      TAPD90 = MAX(OF TAPD14 TAPD15 TAPD16 TAPD18);
      if AGE < 6 then TAPD90 = .;
   end;

   * ----------------------------------------------- ;
   * --- PDI 91 : ACUTE                          --- ;
   * ----------------------------------------------- ;

   if TAPD16 = 1 or TAPD18 = 1 then do;
      TAPD91 = MAX(OF TAPD16 TAPD18);
      if AGE < 6 then TAPD91 = .;
   end;

   * ----------------------------------------------- ;
   * --- PDI 92 : CHRONIC                        --- ;
   * ----------------------------------------------- ;

   if TAPD14 = 1 or TAPD15 = 1 then do;
      TAPD92 = MAX(OF TAPD14 TAPD15);
      if AGE < 6 then TAPD92 = . ;
   end;


 * -------------------------------------------------------------- ;
 * --- EXCLUDE CASES WITH MISSING VALUES FOR DISP             --- ;
 * -------------------------------------------------------------- ;

 if (DISP lt 0) then do;
   TPPD06 = .;
   TPNQ02 = .;
 end;

 * -------------------------------------------------------------- ;
 * --- IDENTIFY TRANSFERS --------------------------------------- ;
 * -------------------------------------------------------------- ;

 * --- TRANSFER FROM ANOTHER ACUTE ---------------- ;
 if ATYPE notin (4) and
    (ASOURCE in (2) or POINTOFORIGINUB04 in ('4'))
 then TRNSFER = 1;
 else TRNSFER = 0;
 if ASOURCE GT .Z and POINTOFORIGINUB04 in (' ') then NOPOUB04 = 1;
 else NOPOUB04 = 0;

 * --- TRANSFER TO ANOTHER ACUTE ---------------- ;

 if DISP in (2) then TRNSOUT = 1;else TRNSOUT = 0;

 * -------------------------------------------------------------- ;
 * --- EXCLUDE TRANSFERS ---------------------------------------- ;
 * -------------------------------------------------------------- ;

 * --- TRANSFER FROM ANOTHER ---------------- ;
 if ATYPE notin (4) and
    (ASOURCE in (2,3) or POINTOFORIGINUB04 in ('4','5','6')) 
 then do;
   TAPD14 = .;
   TAPD15 = .;
   TAPD16 = .;
   TAPD17 = .;
   TAPD18 = .;
   TAPD90 = .;
   TAPD91 = .;
   TAPD92 = .;
   TAPQ09 = .;
 end;

 * --- TRANSFER TO ANOTHER ACUTE ------------------ ;
 if DISP in (2) then do;
   TPPD06 = .;
   TPNQ02 = .;
end;


    if QPPD01 in (.,1) then TPPD01 = .;
    if QPPD02 in (.,1) then TPPD02 = .;
    if QPPD05 in (.,1) then TPPD05 = .;
    if QPPD08 in (.,1) then TPPD08 = .;

    if QPPD09 in (.,1) then TPPD09 = .;
    if QPPD10 in (.,1) then TPPD10 = .;
    if QPPD11 in (.,1) then TPPD11 = .;
    if QPPD12 in (.,1) then TPPD12 = .;
    if QPPD13 in (.,1) then TPPD13 = .;

    if QPNQ01 in (.,1) then TPNQ01 = .;
    if QPNQ03 in (.,1) then TPNQ03 = .;
 

 if QPPD03 in (.,1) then TPPD03 = .; 

 * -------------------------------------------------------------- ;
 * --- LABELS --------------------------------------------------- ;
 * -------------------------------------------------------------- ;

 label
    TRNSFER  = 'TRANSFER FROM ACUTE'
    TRNSOUT  = 'TRANSFER TO ACUTE'
    MAXPR    = 'NUMBER OF PR CODES'
    NOPRDAY  = 'NO PRDAY'
    NOPOUB04 = 'NO POINT OF ORIGIN'
 ;

run;


proc contents data=OUTMSR.&OUTFILE_MEAS. position;
run;

proc print data=OUTMSR.&OUTFILE_MEAS. (OBS=24);
title4 "FIRST 24 RECORDS in OUTPUT data SET &OUTFILE_MEAS.";
run;

*proc means data=OUTMSR.&OUTFILE_MEAS. N NMISS MIN MAX MEAN SUM NOLABELS;
*run;

***----- TO print VARIABLE LABLES COMMENT (DELETE) "NOLABELS" FROM PROC means STATEMENTS -------***;

proc means data = OUTMSR.&OUTFILE_MEAS. n nmiss min max NOLABELS ;
	 var KEY DRG MDC MDRG YEAR DQTR 
         AGEDCAT PAGECAT POPCAT BWHTCAT SEXCAT CONGCAT RACECAT PAYCAT DUALCAT 
         LOS TRNSFER MAXPR NOPOUB04 NOPRDAY TRNSOUT 
         GPPD01 GPPD02 GPPD08 GPPD10 GPPD11 GPPD12;
     title4  "CATEGORICAL VARIABLES and RANGES OF VALUES";
run; quit;


proc means data = OUTMSR.&OUTFILE_MEAS. n nmiss sum NOLABELS ;
     var TAPD14--TAPD18 TAPD90--TAPD92 TAPQ09;
     title "PEDIATRIC INDICATOR NUMERATORS FOR AREA-BASED OR COUNT BASED INDICATORS (COUNT =SUM)";
run; quit;

proc means data = OUTMSR.&OUTFILE_MEAS. n nmiss sum mean  NOLABELS ;
     var TPNQ01--TPNQ03 TPPD01--TPPD13 TPPS17;
     title "PEDIATRIC PROVIDER LEVEL INDICATOR NUMERATOR (=SUM),DENOMINATOR (=N), and OBSERVED RATE (MEAN) ";
run; quit;

proc means data = OUTMSR.&OUTFILE_MEAS. n nmiss sum mean NOLABELS ;
     var TPPD01--TPPD13  TPNQ01--TPNQ03;
     title1 "PEDIATRIC PROVIDER LEVEL INDICATOR NUMERATORS (=SUM),DENOMINATORS (=N), and OBSERVED RATE (MEAN) ";
     title2 "WITH POA MODIFIERS";
run; quit;


