* =============== Program : PDI_AREA_OBSERVED.SAS ===============;
*
*       Title:  AREA OBSERVED RATES FOR AHRQ 
*               PEDIATRIC QUALITY INDICATORS
*  Description:
*         USES PROC SUMMARY TO CALCULATE OBSERVED RATES FOR
*         PEDIATRIC QUALITY INDICATORS ACROSS STRATIFIERS.
*         OUTPUT STRATIFID BY AREA, AGECAT, SEXCAT AND RACECAT 
*         FROM POPULATION FILE AND PDI_ALL_MEASURE OUTPUT.
*         VARIABLES CREATED BY THIS PROGRAM ARE PAPDxx AND OAPDxx

*             >>> AHRQ QI ICD-10 VERSION 6.0.1 <<<
*		        >>> VERSION DATE SEPT, 2016 <<<
*===============================================================;

*PATHNAME specifies the location of the PDI folder which includes 
          Programs, SASdata, and Macros subfolders;
%LET PATHNAME=c:\pathname;                        *<==USER MUST modify;
filename CONTROL "&PATHNAME.\PDI\Programs\PDI_ALL_CONTROL.SAS"; 

%include CONTROL;
/*MACRO TO ADJUST AREA AGGREGATION BASED ON MAREA VALUE IN PDI_ALL_CONTROL.*/

 %MACRO CTY2MA;
    %IF &MALEVL EQ 0 %THEN %DO;
        attrib MAREA length=$5
          label='FIPS STATE COUNTY CODE';
        MAREA = FIPSTCO;
    %END;
    %ELSE %IF &MALEVL EQ 1 %THEN %DO;
        attrib MAREA length=$5
          label='MODIFIED FIPS';
        MAREA = input(put(FIPSTCO,$M1AREA.),$5.);
    %END;
    %ELSE %IF &MALEVL EQ 2 %THEN %DO;
        attrib MAREA length=$5
          label='OMB 1999 METRO AREA';
        MAREA = input(put(FIPSTCO,$M2AREA.),$5.);
    %END;
    %ELSE %IF &MALEVL EQ 3 %THEN %DO;
        attrib MAREA length=$5
          label='OMB 2003 METRO AREA';
        MAREA = input(put(FIPSTCO,$M3AREA.),$5.);
    %END;
 %MEND;

 title2 'PROGRAM PDI_AREA_OBSERVED';
 title3 'AHRQ PEDIATRIC QUALITY INDICATORS: CALCULATE ADJUSTED AREA RATES';

 * ---------------------------------------------------------------- ;
 * --- ADD POPULATION DENOMINATOR                               --- ;
 * --- THIS STEP DETERMINES WHICH AREAS ARE INCLUDED IN THE     --- ;
 * --- OUTPUT BASED ON AREAS IN PDI_ALL_MEASURES OUTPUT.        --- ;
 * ---------------------------------------------------------------- ;

 data   TEMP0 (keep=MAREA);
 set    OUTMSR.&OUTFILE_MEAS.;

 %CTY2MA

 run;
/* IDENTIFY UNIQUE MAREA VALUES IN PDI_ALL_MEASURES OUTPUT. */
 proc   Sort data=TEMP0 out=MAREA nodupkey;
 by     MAREA;
 run;
/* LOAD POPULATION FOR MAREA LEVEL AND YEAR IN PDI_ALL_CONTROL. */
 data QIPOP0;
    length FIPSTCO $5 SEXCAT POPCAT RACECAT 3 
           POP_1995 POP_1996 POP_1997 POP_1998 POP_1999
           POP_2000 POP_2001 POP_2002 POP_2003 POP_2004
           POP_2005 POP_2006 POP_2007 POP_2008 POP_2009 
           POP_2010 POP_2011 POP_2012 POP_2013 POP_2014
           POP_2015 POP 8;

    infile POPFILE missover firstobs=2;

   input FIPSTCO SEXCAT POPCAT RACECAT 
          POP_1995 POP_1996 POP_1997 POP_1998 POP_1999
          POP_2000 POP_2001 POP_2002 POP_2003 POP_2004
          POP_2005 POP_2006 POP_2007 POP_2008 POP_2009
          POP_2010 POP_2011 POP_2012 POP_2013 POP_2014
		  POP_2015;

    %CTY2MA

    POP = POP_&POPYEAR.;

    if POPCAT in (1,2,3,4);

 run;

 proc   Summary data=QIPOP0 nway ;				
 class  MAREA POPCAT SEXCAT RACECAT;
 var    POP;
 output out=QIPOP sum=;
 run;

 proc   Sort data=QIPOP;
 by     MAREA POPCAT SEXCAT RACECAT;
 run;
/* LIMIT POPULATION TOTALS TO MAREA CODES FOUND IN PDI_ALL_MEASURES OUTPUT. */
 data   QIPOP(keep=MAREA POPCAT SEXCAT RACECAT POP);
 merge  MAREA(in=X) QIPOP(in=Y);
 by     MAREA;

 if X and Y;

 run;

* --------------------------------------------------------------- *
 * --- PEDIATRIC QUALITY INDICATOR ADJUSTED RATES --------------- *
 * -------------------------------------------------------------- *
 * AREA-LEVEL INDICATOR DENOMINATORS ARE ADJUSTED BASED ON THE    *
 * COMBINATION OF COUNTY, AGE, SEX, AND RACE IN THE NUMERATOR.    *
 * THIS STEP ITERATES THROUGH THE OUTPUT FROM PDI_MEASURES FOR    *
 * EACH MEASURE AND REDUCES THE POPULATION SUM BY THE NUMERATOR   *
 * TOTAL. THE MOD3 MACRO ADJUSTS THE RESIDENTIAL POPULATION TOTAL *
 * BASED ON THE MEASURE RELAVENT POPULATION. ONLY VALID AREA      *
 * CODES ARE RETURNED. THE MOD3 INPUTS ARE:                       *
 * --- N - AREA MEASURE NUMBER                                --- *
 * --- PD - THE INPATIENT QUALITY INDICATOR NAME WITHOUT THE  --- *
 * ---      PREFIX (A)                                        --- *
 * --- DL - INDICATE IF POPULATION IS NOT ADJUSTED            --- *
 * -------------------------------------------------------------- ;

 %MACRO MOD3(N,PD,DL);

 /* CREATE TEMP TABLE WITH ALL DISCHARGES IN NUMERATOR FOR MEASURE N. */ 

 %IF &DL. = 0 %THEN %DO;

 data   TEMP_2;
 set    OUTMSR.&OUTFILE_MEAS.(keep=KEY FIPSTCO T&PD. POPCAT SEXCAT RACECAT);

 if T&PD. in (1);
 if POPCAT in (1,2,3,4);

 %CTY2MA

 run;
/* SUM THE NUMERATOR 'T' FLAGS BY MAREA POPCAT AGECAT SEXCAT RACECAT. */
 proc   Summary data=TEMP_2 NWAY;
 class  MAREA POPCAT SEXCAT RACECAT;
 var    T&PD.;
 output out=TEMP_3 N=TCOUNT;
 run;

 proc   Sort data=TEMP_3;
 by     MAREA POPCAT SEXCAT RACECAT;
 run;

 /* REDUCE THE DENOMINATOR POPULATION BY THE SUM OF THE NUMERATOR COUNT. */

 data   TEMP_4(drop=TCOUNT N);
 merge  QIPOP(in=X keep=MAREA POPCAT SEXCAT RACECAT POP) 
        TEMP_3(keep=MAREA POPCAT SEXCAT RACECAT TCOUNT);
 by     MAREA POPCAT SEXCAT RACECAT;

 if X;

 N = &N.;

 if POPCAT in (1) then do;
    if N = 14 then POP = POP * 0.60; /* AGE < 2 */
    if N = 15 then POP = .;          /* AGE < 6 */
    if N = 16 then POP = POP * 0.95; /* AGEDAY < 90 */
    if N = 18 then POP = POP * 0.95; /* AGEDAY < 90 */
    if N = 90 then POP = .;          /* AGE < 6 */
    if N = 91 then POP = .;          /* AGE < 6 */
    if N = 92 then POP = .;          /* AGE < 6 */
 end;
 else if POPCAT in (2) then do;
   if N = 15 then POP = POP * 0.80; /* AGE < 6 */
   if N = 90 then POP = POP * 0.80; /* AGE < 6 */
   if N = 91 then POP = POP * 0.80; /* AGE < 6 */
   if N = 92 then POP = POP * 0.80; /* AGE < 6 */
 end;

 if TCOUNT > 0 then PCOUNT = POP - TCOUNT;
 else PCOUNT = POP;

 if PCOUNT < 0 then PCOUNT = 0;

 if PCOUNT = 0 then delete;
 
 run;

 /* FOR NUMERATOR, RETAIN ONLY RECORDS WITH A VALID MAREA CODE. */

 data   TEMP_3(drop=POP);
 merge  TEMP_3(in=X keep=MAREA POPCAT SEXCAT RACECAT TCOUNT)
        QIPOP(keep=MAREA POPCAT SEXCAT RACECAT POP);
 by     MAREA POPCAT SEXCAT RACECAT;

 if X;

 if POP < 0 then PCOUNT = 0;
 else if TCOUNT > 0 then PCOUNT = TCOUNT;
 else PCOUNT = 0;

 if PCOUNT = 0 then delete;
 
 run;

 /* COMBINE THE NUMERATOR AND DENOMINATOR */

 data   TEMP1;
 set    TEMP_3(in=X) TEMP_4;

 if X then T&PD. = 1;
 else T&PD. = 0;

 run;

 %END;
 %ELSE %DO;

 data   TEMP_2;
 set    OUTMSR.&OUTFILE_MEAS.(keep=KEY FIPSTCO T&PD. POPCAT SEXCAT RACECAT);

 if T&PD. in (0,1);
 if POPCAT in (1,2,3,4);

 %CTY2MA

 run;

 proc   Summary data=TEMP_2 NWAY;
 class  T&PD. MAREA POPCAT SEXCAT RACECAT;
 var    T&PD.;
 output out=TEMP_3 N=TCOUNT;
 run;

 proc   Sort data=TEMP_3;
 by     MAREA POPCAT SEXCAT RACECAT;
 run;

 /* RETAIN ONLY RECORDS WITH A VALID MAREA CODE. */

 data   TEMP1;
 merge  TEMP_3(in=X keep=MAREA POPCAT SEXCAT RACECAT TCOUNT T&PD.)
        QIPOP(keep=MAREA POPCAT SEXCAT RACECAT);
 by     MAREA POPCAT SEXCAT RACECAT;

 if X;

 if TCOUNT > 0 then PCOUNT = TCOUNT;
 else PCOUNT = 0;

 if PCOUNT = 0 then delete;
 
 run;

 %END;

  /* ASSIGN POVCAT. */
 data   TEMP1;
 length FEMALE AGECAT1-AGECAT4 FAGECAT1-FAGECAT4
        POVCAT1-POVCAT10 3;
 set    TEMP1;

 if SEXCAT in (2) then FEMALE = 1;
 else FEMALE = 0;

 array ARRY1{4} AGECAT1-AGECAT4;
 array ARRY2{4} FAGECAT1-FAGECAT4;

 do I = 1 TO 4;
    ARRY1(I) = 0; ARRY2(I) = 0;
 end;

 ARRY1(POPCAT) = 1;
 ARRY2(POPCAT) = FEMALE;

 array ARRY3{10} POVCAT1-POVCAT10;

 do I = 1 TO 10;
    ARRY3(I) = 0;
 end;

 PVIDX = put(MAREA,$POVCAT.);

 if PVIDX > 0 then ARRY3(PVIDX) = 1;

 run;
 
 data   TEMP1Y;
 set    TEMP1;
 ONE = 1;
 run;

 * ------------------------------------------------------------------ ;
 * --- AGGREGATE POPULATION COUNTS BY STRATIFIERS                 --- ;
 * --- ADJUSTED POPULATION OUTPUT AFTER ELIMINATING AREAS         --- ;  
 * --- WITHOUT A MEASURE DISCHARGE AND LIMITING TO MEASURE        --- ;
 * --- RELEVANT SUB GROUPS.                                       --- ;
 * ------------------------------------------------------------------ ;

proc   Summary data=TEMP1Y;
 class  MAREA POPCAT SEXCAT RACECAT;
 var    T&PD. ONE;
 output out=ADJ_&PD. SUM(T&PD. ONE)=T&PD. P&PD.;
 weight PCOUNT;
 run;

 data   ADJ_&PD.(keep=MAREA POPCAT SEXCAT RACECAT _TYPE_ T&PD. P&PD.);
 set    ADJ_&PD.;

 if _TYPE_ &TYPELVLA;

 run;

 proc Sort data=ADJ_&PD.;
     by MAREA POPCAT SEXCAT RACECAT;
 run; quit;

 proc   Datasets NOLIST;
 delete TEMP1 TEMP1Y TEMP_2 TEMP_3 TEMP_4;
 run;

 %MEND;

 %MOD3(14,APD14,0);
 %MOD3(15,APD15,0);
 %MOD3(16,APD16,0);
 %MOD3(17,APD17,1);
 %MOD3(18,APD18,0);
 %MOD3(90,APD90,0);
 %MOD3(91,APD91,0);
 %MOD3(92,APD92,0);
 %MOD3(60,APQ09,1);

/* MERGE THE ADJUSTED DENOMINATOR AND NUMERATOR FOR AREA LEVEL PEDIATRIC QUALITY INDICATORS. */
 
data TEMP2Y;
  merge ADJ_APD14 ADJ_APD15 ADJ_APD16 ADJ_APD17 ADJ_APD18 
        ADJ_APD90 ADJ_APD91 ADJ_APD92 ADJ_APQ09;
  by MAREA POPCAT  SEXCAT RACECAT;
run;
/* CALCULATE OBSERVED RATE AS SUM OF NUMERATOR / SUM OF ADJUSTED DENOMINATOR.*/

 * ----------------------------------------------------------------- ;
* --- PEDIATRIC QUALITY INDICATOR (PDI) NAMING CONVENTION:      --- ;
* --- THE FIRST LETTER IDENTIFIES THE PEDIATRIC QUALITY         --- ;
* --- INDICATOR AS ONE OF THE FOLLOWING:
                (T) NUMERATOR ("TOP") - FROM PDI_ALL_MEASURES
                (P) DENOMINATOR ("POPULATION")
                (A) ADJUSTED POPULATION
                (O) OBSERVED RATES (T/P)
* --- THE SECOND LETTER IDENTIFIES THE INDICATOR AS AN AREA (A) --- ;
* --- LEVEL INDICATOR.  THE NEXT TWO CHARACTERS ARE ALWAYS      --- ;
* --- 'PD'. THE LAST TWO DIGITS ARE THE INDICATOR NUMBER.       --- ;
* ----------------------------------------------------------------- ;

 data &OUTFILE_AREAOBS.;
 set TEMP2Y;

 array PPD2{9} PAPD14-PAPD18 PAPD90-PAPD92 PAPQ09;
 array TPD{9}  TAPD14-TAPD18 TAPD90-TAPD92 TAPQ09;
 array OPD{9}  OAPD14-OAPD18 OAPD90-OAPD92 OAPQ09;

 do J = 1 to 9;
    if TPD{J} GT 0 and PPD2{J} GT 0 then OPD{J} = TPD{J} / PPD2{J};
    else if PPD2{J} GT 0 then OPD{J} = 0;
 end;
 
 label
 TAPD14 = 'PDI 14 Asthma Admission Rate (Numerator)'
 TAPD15 = 'PDI 15 Diabetes Short-Term Complications Admission Rate (Numerator)'
 TAPD16 = 'PDI 16 Gastroenteritis Admission Rate (Numerator)'
 TAPD17 = 'PDI 17 Perforated Appendix Admission Rate (Numerator)'
 TAPD18 = 'PDI 18 Urinary Tract Infection Admission Rate (Numerator)'
 TAPD90 = 'PDI 90 Pediatric Quality Overall Composite (Numerator)'
 TAPD91 = 'PDI 91 Pediatric Quality Acute Composite (Numerator)'
 TAPD92 = 'PDI 92 Pediatric Quality Chronic Composite (Numerator)'
 TAPQ09 = 'PQI 09 Low Birth Weight Rate (Numerator)'
 ;
 label
 PAPD14 = 'PDI 14 Asthma Admission Rate (Population)'
 PAPD15 = 'PDI 15 Diabetes Short-Term Complications Admission Rate (Population)'
 PAPD16 = 'PDI 16 Gastroenteritis Admission Rate (Population)'
 PAPD17 = 'PDI 17 Perforated Appendix Admission Rate (Population)'
 PAPD18 = 'PDI 18 Urinary Tract Infection Admission Rate (Population)'
 PAPD90 = 'PDI 90 Pediatric Quality Overall Composite (Population)'
 PAPD91 = 'PDI 91 Pediatric Quality Acute Composite (Population)'
 PAPD92 = 'PDI 92 Pediatric Quality Chronic Composite (Population)'
 PAPQ09 = 'PQI 09 Low Birth Weight Rate (Population)'
 ;
 label
 OAPD14 = 'PDI 14 Asthma Admission Rate (Observed)'
 OAPD15 = 'PDI 15 Diabetes Short-Term Complications Admission Rate (Observed)'
 OAPD16 = 'PDI 16 Gastroenteritis Admission Rate (Observed)'
 OAPD17 = 'PDI 17 Perforated Appendix Admission Rate (Observed)'
 OAPD18 = 'PDI 18 Urinary Tract Infection Admission Rate (Observed)'
 OAPD90 = 'PDI 90 Pediatric Quality Overall Composite (Observed)'
 OAPD91 = 'PDI 91 Pediatric Quality Acute Composite (Observed)'
 OAPD92 = 'PDI 92 Pediatric Quality Chronic Composite (Observed)'
 OAPQ09 = 'PQI 09 Low Birth Weight Rate (Observed)'
 _TYPE_ = 'STRATIFICATION LEVEL'
 ;

 drop J;

 run;

 proc Sort data=&OUTFILE_AREAOBS. OUT=OUTAOBS.&OUTFILE_AREAOBS.;
 by MAREA POPCAT SEXCAT RACECAT;
 run;

proc Datasets NOLIST;
  delete MAREA QIPOP QIPOP0 TEMP0 TEMP2Y
         ADJ_APD14 ADJ_APD15 ADJ_APD16 ADJ_APD17 ADJ_APD18 
         ADJ_APD90 DJ_APD92 ADJ_APQ09;
run; quit;

 * ------------------------------------------------------- ;
 * --- CONTENTS AND MEANS OF AREA OBSERVED OUTPUT FILE --- ;
 * ------------------------------------------------------- ;

 proc Contents data=OUTAOBS.&OUTFILE_AREAOBS. position;
 run;

 ***----- TO PRINT VARIABLE LABLES COMMENT (DELETE) "NOLABELS" FROM PROC MEANS STATEMENTS -------***;

proc Means data=OUTAOBS.&OUTFILE_AREAOBS. (WHERE=(_TYPE_ in (8))) n nmiss min max sum nolabels;
   var TAPD14-TAPD18 TAPD90-TAPD92 TAPQ09;
   title  'SUMMARY OF PEDIATRIC AREA-LEVEL INDICATOR OVERALL NUMERATOR (SUM) WHEN _TYPE_=8';
run; quit;

proc Means data=OUTAOBS.&OUTFILE_AREAOBS. (WHERE=(_TYPE_ in (8))) n nmiss min max sum nolabels;
   var PAPD14-PAPD18 PAPD90-PAPD92 PAPQ09 ;
   title  'SUMMARY OF PEDIATRIC AREA-LEVEL INDICATOR OVERALL DENOMINATOR (SUM) WHEN _TYPE_=8';
run; quit;

proc Means data=OUTAOBS.&OUTFILE_AREAOBS. (WHERE=(_TYPE_ in (8))) n nmiss min max mean nolabels;
   var OAPD14-OAPD18 OAPD90-OAPD92 OAPQ09;
   title  'SUMMARY OF PEDIATRIC AREA-LEVEL OBSERVED INDICATOR AVERAGE RATES(MEAN) WHEN _TYPE_=8';
run; quit;

 * -------------------------------------------------------------- ;
 * --- PRINT AREA OBSERVED MEANS FILE TO SAS OUTPUT          ---- ;
 * -------------------------------------------------------------- ;

 %MACRO PRT2;

 %IF &PRINT. = 1 %THEN %DO;

 %MACRO PRT(PD,TEXT);

 proc  PRINT data=OUTAOBS.&OUTFILE_AREAOBS. label SPLIT='*';
 var   MAREA POPCAT SEXCAT RACECAT TA&PD. PA&PD. OA&PD. ;
 label MAREA    = "MAREA"
       POPCAT   = "POPCAT"
       SEXCAT   = "SEXCAT"
       RACECAT  = "RACECAT"
       TA&PD.   = "TA&PD.*(Numerator)"
       PA&PD.   = "PA&PD.*(Denominator)"
       OA&PD.   = "OA&PD.*(Observed)"
       ;
 format POPCAT POPCAT.   
        SEXCAT SEXCAT.
        RACECAT RACECAT.
        TA&PD. PA&PD. COMMA13.0
        OA&PD. 8.6
        ;
 title4 "Indicator &PD.: &TEXT";
 run;

 %MEND PRT;

 %PRT(PD14,Asthma Admission Rate);
 %PRT(PD15,Diabetes Short-Term Complications Admission Rate);
 %PRT(PD16,Gastroenteritis Admission Rate);
 %PRT(PD17,Perforated Appendix Admission Rate);
 %PRT(PD18,Urinary Tract Infection Admission Rate);
 %PRT(PQ09,Low Birth Weight Rate);

 %END;

 %MEND PRT2;

 %PRT2; 

 * -------------------------------------------------------------- ;
 * --- WRITE SAS OUTPUT DATA SET TO COMMA-DELIMITED TEXT FILE --- ;
 * --- FOR EXPORT INTO SPREADSHEETS ----------------------------- ;
 * -------------------------------------------------------------- ;

 %MACRO TEXT;

 %IF &TXTAOBS. = 1  %THEN %DO;
	%LET TYPEARN  = %sysfunc(tranwrd(&TYPELVLA.,%str(,),_));
	%LET TYPEARN2  = %sysfunc(compress(&TYPEARN.,'(IN )'));
	%let PRCSVREF = %sysfunc(pathname(PDTXTAOB));
	%let PDCSVRF2 =  %sysfunc(tranwrd(&PRCSVREF.,.,_&TYPEARN2..));
 data _NULL_;
 set OUTAOBS.&OUTFILE_AREAOBS.;
 file "&PDCSVRF2." lrecl=1000;
 if _N_=1 then do;

  put "MAREA"  "," "Age"  "," "Sex"  "," "Race"  "," "Type" ","
 "TAPD14" "," "TAPD15" "," "TAPD16" "," 
 "TAPD17" "," "TAPD18" ","
 "TAPD90" "," "TAPD91" "," "TAPD92" ","
 "TAPQ09" "," 
 "PAPD14" "," "PAPD15" "," "PAPD16" ","
 "PAPD17" "," "PAPD18" ","
 "PAPD90" "," "PAPD91" "," "PAPD92" ","
 "PAPQ09" "," 
 "OAPD14" "," "OAPD15" "," "OAPD16" ","
 "OAPD17" "," "OAPD18" ","
 "OAPD90" "," "OAPD91" "," "OAPD92" ","
 "OAPQ09"  
;
 end;

 put MAREA $5. "," POPCAT 3. "," SEXCAT 3. "," RACECAT 3.  "," _TYPE_ 2.  ","
 (TAPD14-TAPD18 TAPD90-TAPD92 TAPQ09) (7.0 ",")
 ","
 (PAPD14-PAPD18 PAPD90-PAPD92 PAPQ09) (13.2 ",")
 ","
 (OAPD14-OAPD18 OAPD90-OAPD92 OAPQ09) (12.10 ",")
 ;
 run;

 %END;

 %MEND TEXT;

 %TEXT;
