*======================= PROGRAM: IQI_ALL_MEASURES.SAS ========================;
*
*  Description:
*         ASSIGNS THE IQI OUTCOME MEASURE OF INTEREST AND TO INPATIENT RECORDS. 
*         VARIABLES CREATED BY THIS PROGRAM ARE TPIQxx, TAIQxx, AND STRATIFIERS;
*
*                     >>>  AHRQ QI ICD-10  VERSION 6.0.1 <<<
*		                >>> VERSION DATE SEPT, 2016 <<<
*
*  USER NOTE1:  Make sure you have created the format library
*              using IQI_FORMATS.SAS BEFORE running this program.
*
*  USER NOTE2: The AHRQ QI software does not support the calculation of weighted 
*            estimates and standard errors using complex sampling designs. 
*===============================================================================;

*PATHNAME specifies the location of the IQI  folder which includes 
          Programs, SASdata, and Macros subfolders;

%LET PATHNAME= c:\Pathname;                *<===USER MUST modify;
filename CONTROL "&PATHNAME.\IQI\Programs\IQI_ALL_CONTROL.SAS"; 

%INCLUDE CONTROL;

 title2 'IQI_ALL_MEASURES PROGRAM';
 title3 'AHRQ INPATIENT QUALITY INDICATORS: ASSIGN QIS TO INPATIENT DATA';

 * ----------------------------------------------------------------- ;
 * --- CREATE A PERMANENT DATASET CONTAINING ALL RECORDS THAT    --- ; 
 * --- WILL NOT BE INCLUDED IN ANALYSIS BECAUSE KEY VARIABLE     --- ;
 * --- VALUES ARE MISSING. REVIEW AFTER RUNNING IQI_ALL_MEASURES.--- ;
 * ----------------------------------------------------------------- ;

 data   OUTMSR.&DELFILE.
 	(keep=KEY HOSPID SEX AGE DX1 MDC YEAR DQTR);
 set 	INMSR.&DISCHARGE.;
 if (AGE lt 0) or (AGE lt 18 and MDC notin (14)) or (SEX le 0) or 
	(DX1 in (' ')) or (DQTR le .Z) or (YEAR le .Z);
 run;
 * --- Include standard diagnosis and procedure macros. ---* ;
 %include MacLib(IQI_Dx_Px_Macros.sas) ;

 * -------------------------------------------------------------- ;
 * --- INPATIENT QUALITY INDICATOR (IQI) NAMING CONVENTION:   --- ;
 * --- THE FIRST LETTER IDENTIFIES THE INPATIENT QUALITY      --- ;
 * --- INDICATOR AS ONE OF THE FOLLOWING:
                (T) NUMERATOR ("TOP")
 * --- THE SECOND LETTER IDENTIFIES THE IQI AS A PROVIDER (P) --- ;
 * --- OR AN AREA (A) LEVEL INDICATOR.  THE                   --- ;
 * --- NEXT TWO CHARACTERS ARE ALWAYS 'IQ'. THE LAST TWO      --- ;
 * --- DIGITS ARE THE INDICATOR NUMBER (WITHIN THAT SUBTYPE). --- ;
 * -------------------------------------------------------------- ;

 data   OUTMSR.&OUTFILE_MEAS.
    (keep=KEY HOSPID FIPST FIPSTCO DRG MDC SEX AGE YEAR DQTR
          AGECAT POPCAT SEXCAT RACECAT PAYCAT DUALCAT LOS 
          TRNSFER MAXDX MAXPR NOPOUB04 NOPRDAY TRNSOUT 
          TPIQ01  TPIQ02   TPIQ02A  TPIQ02B TPIQ04  TPIQ04A--TPIQ04D TPIQ05-TPIQ09 
          TPIQ09A  TPIQ09B  TPIQ11  TPIQ11A--TPIQ11D TPIQ12-TPIQ17 
          TPIQ17A--TPIQ17C TPIQ18-TPIQ20 TPIQ30-TPIQ34
          TPIQ21-TPIQ25    TAIQ26-TAIQ29);

 set   INMSR.&DISCHARGE.
    (keep=KEY HOSPID DRG MDC SEX AGE PSTCO RACE YEAR DQTR
          PAY1 PAY2 DISP LOS ASOURCE POINTOFORIGINUB04 
          DX1-DX&NDX. PR1-PR&NPR. %ADDPRDAY);

 * -------------------------------------------------------------- ;
 * --- DEFINE MDC ----------------------------------------------- ;
 * -------------------------------------------------------------- ;
 attrib MDCNEW length=3
   label='IMPUTED MDC';

 if MDC notin (01,02,03,04,05,06,07,08,09,10,
               11,12,13,14,15,16,17,18,19,20,
               21,22,23,24,25)
 then do;
    MDCNEW = put(DRG,MDCF2T.);
    if MDCNEW in (01,02,03,04,05,06,07,08,09,10,
                  11,12,13,14,15,16,17,18,19,20,
                  21,22,23,24,25)
    then MDC=MDCNEW;
    else do;
       if DRG in (999) then MDC = 0;
       else put "INVALID MDC KEY: " KEY " MDC " MDC " DRG " DRG ;
    end;
 end;
 

 * ------------------------------------------------------------------------ ;
 * -- DELETE RECORDS WITH MISSING VALUES FOR AGE, SEX, DX1, DQTR, & YEAR -- ;
 * -- DELETE NON ADULT RECORDS                                           -- ;
 * ------------------------------------------------------------------------ ;
 if SEX le 0 then delete;
 if AGE lt 0 then delete;
 if AGE lt 18 and MDC notin (14) then delete;
 if DX1 in (' ') then delete;
 if DQTR le .Z then delete;
 if YEAR le .Z then delete;


 * -------------------------------------------------------------- ;
 * --- CALCULATE NUMBER OF DX CODES ----------------------------- ;
 * -------------------------------------------------------------- ;
 array ARRY1{&NDX.} DX1-DX&NDX.;

 MAXDX = 0;  

 do I = 1 TO &NDX.;
    if ARRY1(I) notin (' ') then do;
       MAXDX + 1;
    end;
 end;


 * -------------------------------------------------------------- ;
 * --- COUNT THE NUMBER OF PR CODES ----------------------------- ;
 * -------------------------------------------------------------- ;
 array ARRY3{&NPR.} PR1-PR&NPR.;
 array ARRY6{&NPR.} PRDAY1-PRDAY&NPR.;

 MAXPR = 0; CNTPRDAY = 0;
 do I = 1 TO &NPR.;
    if ARRY3(I) notin (' ') then MAXPR + 1;
    if ARRY6(I) ge 0 then CNTPRDAY + 1;
 end;

 if &PRDAY. EQ 0 or CNTPRDAY = 0 then NOPRDAY = 1;
 else NOPRDAY = 0;

 * ------------------------------------------------------------- ;
 * --- DEFINE FIPS STATE AND COUNTY CODES ---------------------- ;
 * ------------------------------------------------------------- ;
 attrib FIPSTCO length=$5
   label='FIPS STATE COUNTY CODE';
 FIPSTCO = put(PSTCO,Z5.);

 attrib FIPST length=$2
   label='STATE FIPS CODE';
 FIPST = SUBSTR(FIPSTCO,1,2);

* -------------------------------------------------------------- ;
 * --- DEFINE ICD-10-CM VERSION -------------------------------- ;
 * ------------------------------------------------------------- ;
 attrib ICDVER length=3
   label='ICD-10-CM VERSION';

 ICDVER = 0;
 if (YEAR in (2015) and DQTR in (4))     then ICDVER = 33;
 else if (YEAR in (2016) and DQTR in (1,2,3)) then ICDVER = 33;
 else ICDVER=33;

 * ------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: PAYER CATEGORY ----------------------- ;
 * ------------------------------------------------------------- ;
 attrib PAYCAT length=3
   label='PATIENT PRIMARY PAYER';

 select (PAY1);
   when (1)  PAYCAT = 1;
   when (2)  PAYCAT = 2;
   when (3)  PAYCAT = 3;
   when (4)  PAYCAT = 4;
   when (5)  PAYCAT = 5;
   otherwise PAYCAT = 6;
 end; 


 * ------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: RACE CATEGORY ------------------------ ;
 * ------------------------------------------------------------- ;
 attrib RACECAT length=3
   label='PATIENT RACE/ETHNICITY';

 select (RACE);
   when (1)  RACECAT = 1;
   when (2)  RACECAT = 2;
   when (3)  RACECAT = 3;
   when (4)  RACECAT = 4;
   when (5)  RACECAT = 5;
   otherwise RACECAT = 6;
 end; 

 attrib DUALCAT length=3
   label='PATIENT DUAL ELIGIBLE';

 if (PAY1 in (1) and PAY2 in (2)) or
    (PAY1 in (2) and PAY2 in (1)) 
 then DUALCAT = 1; else DUALCAT = 0;
 

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: AGE CATEGORY  ------------------------- ;
 * -------------------------------------------------------------- ;
 attrib AGECAT length=3
   label='PATIENT AGE';

 select;
   when (      AGE < 18)  AGECAT = 0;
   when (18 <= AGE < 40)  AGECAT = 1;
   when (40 <= AGE < 65)  AGECAT = 2;
   when (65 <= AGE < 75)  AGECAT = 3;
   when (75 <= AGE     )  AGECAT = 4;
   otherwise AGECAT = 0;
 end;


 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: SEX CATEGORY  ------------------------- ;
 * -------------------------------------------------------------- ;
 attrib SEXCAT length=3
   label='PATIENT SEX';

 select (SEX);
   when (1)  SEXCAT = 1;
   when (2)  SEXCAT = 2;
   otherwise SEXCAT = 0;
 end;


 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: POPULATION CATEGORY ------------------- ;
 * -------------------------------------------------------------- ;
 attrib POPCAT length=3
   label='PATIENT AGE';

 POPCAT=put(AGE,AGEFMT.);

 * -------------------------------------------------------------- ;
 * --- DEFINE PROVIDER LEVEL VOLUME INDICATORS ------------------ ;
 * -------------------------------------------------------------- ;

 attrib
 TPIQ01 length=8
   label='IQI 01 Esophageal Resection Volume (Numerator)'
 TPIQ02 length=8
   label='IQI 02 Pancreatic Resection Volume (Numerator)'
 TPIQ02A length=8
   label='IQI 02 Pancreatic Resection Volume Stratum A: with Pancreatic Cancer Diagnosis (Numerator)'
 TPIQ02B length=8
   label='IQI 02 Pancreatic Resection Volume Stratum B: without Pancreatic Cancer Diagnosis (Numerator)'
 TPIQ04 length=8
   label='IQI 04 Abdominal Aortic Aneurysm (AAA) Repair Volume (Numerator)'
 TPIQ04A length=8
   label='IQI 04 Abdominal Aortic Aneurysm Repair Volume Stratum A: Open repair of ruptured AAA (Numerator)'
 TPIQ04B length=8
   label='IQI 04 Abdominal Aortic Aneurysm Repair Volume Stratum B: Open repair of unruptured AAA (Numerator)'
 TPIQ04C length=8
   label='IQI 04 Abdominal Aortic Aneurysm Repair Volume Stratum C: Endovascular repair of ruptured AAA (Numerator)'
 TPIQ04D length=8
   label='IQI 04 Abdominal Aortic Aneurysm Repair Volume Stratum D: Endovascular repair of unruptured AAA (Numerator)'
 TPIQ05 length=8
   label='IQI 05 Coronary Artery Bypass Graft (CABG) Volume (Numerator)'
 TPIQ06 length=8
   label='IQI 06 Percutaneous Coronary Intervention (PCI) Volume (Numerator)'
 TPIQ07 length=8
   label='IQI 07 Carotid Endarterectomy Volume (Numerator)'
;

 * -------------------------------------------------------------- ;
 * --- DEFINE PROVIDER LEVEL MORTALITY INDICATORS --------------- ;
 * -------------------------------------------------------------- ;
 attrib
 TPIQ08 length=8
   label='IQI 08 Esophageal Resection Mortality Rate (Numerator)'
 TPIQ09 length=8                           
   label='IQI 09 Pancreatic Resection Mortality Rate (Numerator)'
 TPIQ09A length=8                           
   label='IQI 09 Pancreatic Resection Mortality Rate Stratum A: Presence of Pancreatic Cancer Diagnosis (Numerator)'
 TPIQ09B length=8                           
   label='IQI 09 Pancreatic Resection Mortality Rate Stratum B: Absence of Pancreatic Cancer Diagnosis (Numerator)'
 TPIQ11 length=8
   label='IQI 11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate (Numerator)'
 TPIQ11A length=8
   label='IQI 11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum A: Open repair of ruptured AAA (Numerator)'
 TPIQ11B length=8
   label='IQI 11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum B: Open repair of unruptured AAA (Numerator)'
 TPIQ11C length=8
   label='IQI 11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum C: Endovascular repair of ruptured AAA (Numerator)'
 TPIQ11D length=8
   label='IQI 11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum D: Endovascular repair of unruptured AAA (Numerator)'
 TPIQ12 length=8
   label='IQI 12 Coronary Artery Bypass Graft (CABG) Mortality Rate (Numerator)'
 TPIQ13 length=8
   label='IQI 13 Craniotomy Mortality Rate (Numerator)'
 TPIQ14 length=8
   label='IQI 14 Hip Replacement Mortality Rate (Numerator)'
 TPIQ15 length=8
   label='IQI 15 Acute Myocardial Infarction (AMI) Mortality Rate (Numerator)'
 TPIQ16 length=8
   label='IQI 16 Heart Failure Mortality Rate (Numerator)'
 TPIQ17 length=8
   label='IQI 17 Acute Stroke Mortality Rate (Numerator)'
 TPIQ17A length=8
   label='IQI 17 Acute Stroke Mortality Rate Stratum A: Subarachnoid hemorrhage (Numerator)'
 TPIQ17B length=8
   label='IQI 17 Acute Stroke Mortality Rate Stratum B: Intracerebral hemorrhage (Numerator)'
 TPIQ17C length=8
   label='IQI 17 Acute Stroke Mortality Rate Stratum C: Ischemic stroke (Numerator)'
 TPIQ18 length=8
   label='IQI 18 Gastrointestinal Hemorrhage Mortality Rate (Numerator)'
 TPIQ19 length=8
   label='IQI 19 Hip Fracture Mortality Rate (Numerator)'
 TPIQ20 length=8
   label='IQI 20 Pneumonia Mortality Rate (Numerator)'
;
  
 * -------------------------------------------------------------- ;
 * --- DEFINE ADDITIONAL PROVIDER LEVEL MORTALITY INDICATORS ---- ;
 * -------------------------------------------------------------- ;
 attrib
 TPIQ30 length=8
   label='IQI 30 Percutaneous Coronary Intervention (PCI) Mortality Rate (Numerator)'
 TPIQ31 length=8
   label='IQI 31 Carotid Endarterectomy Mortality Rate (Numerator)'
 TPIQ32 length=8
   label='IQI 32 Acute Myocardial Infarction (AMI) Mortality Rate, Without Transfer Cases (Numerator)'
;

  * -------------------------------------------------------------- ;
 * --- DEFINE PROVIDER LEVEL UTILIZATION INDICATORS ------------- ;
 * -------------------------------------------------------------- ;
 attrib
 TPIQ21 length=8
   label='IQI 21 Cesarean Delivery Rate, Uncomplicated (Numerator)'
 TPIQ22 length=8
   label='IQI 22 Vaginal Birth After Cesarean (VBAC) Delivery Rate, Uncomplicated (Numerator)'
 TPIQ23 length=8
   label='IQI 23 Laparoscopic Cholecystectomy Rate (Numerator)'
 TPIQ24 length=8
   label='IQI 24 Incidental Appendectomy in the Elderly Rate (Numerator)'
 TPIQ25 length=8
   label='IQI 25 Bilateral Cardiac Catheterization Rate (Numerator)'
;

 * -------------------------------------------------------------- ;
 * --- DEFINE ADDITIONAL PROVIDER LEVEL UTILIZATION INDICATORS -- ;
 * -------------------------------------------------------------- ;
 attrib
 TPIQ33 length=8
   label='IQI 33 Primary Cesarean Delivery Rate, Uncomplicated (Numerator)'
 TPIQ34 length=8
   label='IQI 34 Vaginal Birth After Cesarean (VBAC) Rate, All (Numerator)'
;

 * -------------------------------------------------------------- ;
 * --- DEFINE AREA LEVEL UTILIZATION INDICATORS ----------------- ;
 * -------------------------------------------------------------- ;
 attrib
 TAIQ26 length=8
   label='IQI 26 Coronary Artery Bypass Graft (CABG) Rate (Numerator)'
 TAIQ27 length=8
   label='IQI 27 Percutaneous Coronary Intervention (PCI) Rate (Numerator)'
 TAIQ28 length=8
   label='IQI 28 Hysterectomy Rate (Numerator)'
 TAIQ29 length=8
   label='IQI 29 Laminectomy or Spinal Fusion Rate (Numerator)'
;
 
 * ------------------------------------------------------- ;
 * --- CONSTRUCT PROVIDER LEVEL INDICATORS --------------- ;
 * ------------------------------------------------------- ;

 * --- CONSTRUCT PROVIDER LEVEL VOLUME INDICATORS --- ;

 * -------------------------------------------------- ;
 * --- IQI 01 : VOLUME ESOPHAGEAL RESECTION       --- ;
 * -------------------------------------------------- ;

   if (%MPR($PRESOPP.) or 
      (%MPR($PRESO2P.) and %MDX($PRESOPD.))) 
   then

      TPIQ01 = 1;

  
 * -------------------------------------------------- ;
 * --- IQI 02 : VOLUME PANCREATIC RESECTION       --- ;
 * -------------------------------------------------- ;

   if (%MPR($PRPANCP.) or %MPR($PRPAN3P.)) then do;

      	TPIQ02 = 1;

	   	if (%MDX($PRPANCD.)) then TPIQ02A = 1 ;

	   	else TPIQ02B = 1 ;

	end;

   	if %MDX($PRPAN2D.) then do;

		TPIQ02 = .;
     	TPIQ02A = .; 
     	TPIQ02B = .;

	end;


 * -------------------------------------------------- ;
 * --- IQI 04 : VOLUME AAA REPAIR                 --- ;
 * -------------------------------------------------- ;

   if (%MDX($PRAAARD.) or %MDX($PRAAA2D.)) and 
      (%MPR($PRAAARP.)  or %MPR($PRAAA2P.)) then

      TPIQ04 = 1;


   * --- VOLUME AAA REPAIR (STRATIFICATION)               --- ;
   * --- stratification priority according to prior probability of death --- ;


        /** IQI 04A : OPEN REPAIR - RUPTURED ***/ 
		if %MPR($PRAAARP.) and %MDX($PRAAARD.) then do;
		   TPIQ04A = 1;
		end;

		/** IQI 04C : ENDOVASCULAR REPAIR  - RUPTURED ***/
		else if %MPR($PRAAA2P.) and %MDX($PRAAARD.) then do;
		   TPIQ04C = 1;
		end;

		/** IQI 04B : OPEN REPAIR - UNRUPTURED ***/
		else if %MPR($PRAAARP.) and %MDX($PRAAA2D.) then do;
		   TPIQ04B = 1;
		end;

	    /** IQI 04D : ENDOVASCULAR REPAIR - UNRUPTURED ***/
		else if %MPR($PRAAA2P.) and %MDX($PRAAA2D.) then do;
		   TPIQ04D = 1;
		end;


 * -------------------------------------------------- ;
 * --- IQI 05 : VOLUME CABG                       --- ;
 * -------------------------------------------------- ;

   if %MPR($PRCABGP.) then

      TPIQ05 = 1;

 * -------------------------------------------------- ;
 * --- IQI 06 : VOLUME PTCA                       --- ;
 * -------------------------------------------------- ;

   if %MPR($PRPTCAP.) then

      TPIQ06 = 1;

 * -------------------------------------------------- ;
 * --- IQI 07 : VOLUME CAROTID ENDARTERECTOMY     --- ;
 * -------------------------------------------------- ;

   if %MPR($PRCEATP.) then

      TPIQ07 = 1;


 * --- CONSTRUCT PROVIDER LEVEL MORTALITY INDICATORS --- ;


 * -------------------------------------------------- ;
 * --- IQI 08 : IN-HOSP MORT ESOPHAGEAL RESECTION --- ;
 * -------------------------------------------------- ;

   if MDC notin (14) and
      ((%MPR($PRESOPP.) and (%MDX($PRESOPD.) or %MDX($PRESO2D.))) or 
       (%MPR($PRESO2P.) and %MDX($PRESOPD.))) 
   then do;

      TPIQ08 = 0; 
      if DISP in (20) then TPIQ08 = 1;

end;

  
 * -------------------------------------------------- ; 
 * --- IQI 09 : IN-HOSP MORT PANCREATIC RESECTION --- ;
 * -------------------------------------------------- ;

   if MDC notin (14) and (%MPR($PRPANCP.) or %MPR($PRPAN3P.)) then do;

      TPIQ09 = 0; 
      if DISP in (20) then TPIQ09 = 1;

	  if %MDX($PRPANCD.) then do;
			TPIQ09A = 0; 
           	if DISP in (20) then TPIQ09A = 1;
	  end;
	  else do;
	       TPIQ09B = 0;  
 		   if DISP in (20) then TPIQ09B = 1;
	  end;

	 * ---------------------------------------------- ;
	 * --- EXCLUDE ACUTE PANCREATITIS             --- ;
	 * ---------------------------------------------- ;

      if %MDX($PRPAN2D.) then do;
		   TPIQ09 = .;
		   TPIQ09A = .;
		   TPIQ09B = .;
	  end;

    end;


 * -------------------------------------------------- ;
 * --- IQI 11 : IN-HOSP MORT AAA REPAIR           --- ;
 * -------------------------------------------------- ;

   if MDC notin (14) and 
      (%MDX($PRAAARD.) or %MDX($PRAAA2D.)) and 
      (%MPR($PRAAARP.) or %MPR($PRAAA2P.))

      then do;

      TPIQ11 = 0;  

      if DISP in (20) then TPIQ11 = 1;

   end;

       
   * --- IN-HOSP MORT AAA REPAIR (STRATIFICATION)          --- ;
   * --- stratification priority according to prior probability of death --- ;
   
   if MDC notin (14) then do;

      /** IQI 11A : OPEN REPAIR- RUPTURED ***/
	   if %MPR($PRAAARP.) and %MDX($PRAAARD.) then do;
	      TPIQ11A = 0; 
		  if DISP in (20) then TPIQ11A = 1;
	   end;

	  /** IQI 11C : ENDOVASCULAR REPAIR - RUPTURED ***/
	   else if %MPR($PRAAA2P.) and %MDX($PRAAARD.) then do;
	         TPIQ11C = 0;
			 if DISP in (20) then TPIQ11C = 1;
	   end;

	  /** IQI 11B : OPEN REPAIR- UNRUPTURED ***/
	   else if %MPR($PRAAARP.) and %MDX($PRAAA2D.) then do;
	         TPIQ11B = 0;
             if DISP in (20) then TPIQ11B = 1;

	   end;

	  /** IQI 11D : ENDOVASCULAR REPAIR  - UNRUPTURED ***/
	   else if %MPR($PRAAA2P.) and %MDX($PRAAA2D.) then do;
	         TPIQ11D = 0;
			 if DISP in (20) then TPIQ11D = 1;
	   end;

   end;


 * -------------------------------------------------- ;
 * --- IQI 12 : IN-HOSP MORT CABG                 --- ;
 * -------------------------------------------------- ;

   if MDC notin (14) and (AGE >= 40) and
      %MPR($PRCABGP.) 
   then do;

      TPIQ12 = 0; 
      if DISP in (20) then TPIQ12 = 1;

   end;

 * -------------------------------------------------- ;
 * --- IQI 13 : IN-HOSP MORT CRANIOTOMY           --- ;
 * -------------------------------------------------- ;

   if %MDR($CRANIO2G.) then do;

      TPIQ13 = 0; 
      if DISP in (20) then TPIQ13 = 1;

	  *** Exclude Head Trauma;
      if %MDX1($HTRAUID.) then TPIQ13 = .; 

   end;

 * -------------------------------------------------- ;
 * --- IQI 14 : IN-HOSP MORT HIP REPLACEMENT      --- ;
 * -------------------------------------------------- ;

   if MDC notin (14) and 
      %MPR($MTHIPRP.) and %MDX($MTHIPRD.) 
   then do;

      TPIQ14 = 0;
      if DISP in (20) then TPIQ14 = 1;

      *** Exclude hip fracture;
      if %MDX($MTHIPFD.) then TPIQ14 = .;  

   end;

 * -------------------------------------------------- ;
 * --- IQI 15 : IN-HOSP MORT AMI                  --- ;
 * -------------------------------------------------- ;

   if MDC notin (14) and 
      %MDX1($MRTAMID.) then do;

      TPIQ15 = 0;
      TPIQ32 = 0;

       if DISP in (20) then do;
         TPIQ15 = 1;
         TPIQ32 = 1;
      end;

   end;

   
 * -------------------------------------------------- ;
 * --- IQI 16 : IN-HOSP MORT CHF                  --- ;
 * -------------------------------------------------- ;

   if MDC notin (14) and
      %MDX1($MRTCHFD.) 
   then do;

      TPIQ16 = 0;
      if DISP in (20) then TPIQ16 = 1;

   end;


 * -------------------------------------------------- ;
 * --- IQI 17 : IN-HOSP MORT STROKE               --- ;
 * -------------------------------------------------- ;

   if MDC notin (14) and
      (%MDX1($MRTCV2A.) or %MDX1($MRTCV3D.) or %MDX1($MRTCV4D.))
   then do;

      TPIQ17 = 0; 

      if DISP in (20) then TPIQ17 = 1;

   end;

   * --- IN-HOSP MORT STROKE   (STRATIFICATION)            --- ;
   * --- stratification priority according to prior probability of death ---;

   /* IQI 17 B : STRATUM 2: INTRACEREBRAL HEMORRHAGIC STROKE */
   if MDC notin (14) and %MDX1($MRTCV3D.) then do;

      TPIQ17B = 0;

      if DISP in (20) then TPIQ17B = 1;
 
   end;

   /* IQI 17A : STRATUM 1: SUBARACHNOID HEMORRHAGE  */

   else if MDC notin (14) and %MDX1($MRTCV2A.) then do;

      TPIQ17A = 0;

      if DISP in (20) then TPIQ17A = 1;
    end;

  /* IQI 17C : STRATUM 3: ISCHEMIC HEMORRHAGIC STROKE */

   else if MDC notin (14) and %MDX1($MRTCV4D.) then do;

      TPIQ17C = 0;

      if DISP in (20) then TPIQ17C = 1;
   end;

 * -------------------------------------------------- ;
 * --- IQI 18 : IN-HOSP MORT GI HEMORRHAGE        --- ;
 * -------------------------------------------------- ;

   if MDC notin (14) and
      %MDX1($MRTGIHD.) 
   then do;

      TPIQ18 = 0;
      if DISP in (20) then TPIQ18 = 1;

   end;

 * -------------------------------------------------- ;
 * --- IQI 19 : IN-HOSP MORT HIP FRACTURE         --- ;
 * -------------------------------------------------- ;

   if MDC notin (14) and (AGE >= 65) and
      %MDX1($MTHIPFD.) 
   then do;

      TPIQ19 = 0; 
      if DISP in (20) then TPIQ19 = 1;

      *** Exclude periprosthetic fracture;
      if %MDX($MTHIP2D.) then do;
         TPIQ19 = .; 
      end;

   end;

 * -------------------------------------------------- ;
 * --- IQI 20 : IN-HOSP MORT PNEUMONIA            --- ;
 * -------------------------------------------------- ;

   if MDC notin (14) and
      %MDX1($MTPNEUD.) 
   then do;

      TPIQ20 = 0;
      if DISP in (20) then TPIQ20 = 1;

   end;


 * --- CONSTRUCT ADDITIONAL PROVIDER LEVEL MORTALITY INDICATORS - ;

 * -------------------------------------------------- ;
 * --- IQI 30 : IN-HOSP MORTALITY PTCA            --- ;
 * -------------------------------------------------- ;

   if MDC notin (14) and (AGE >= 40) and 
      %MPR($PRPTCAP.) 
   then do;

      TPIQ30 = 0;
      if DISP in (20) then TPIQ30 = 1;

   end;

 * -------------------------------------------------- ;
 * --- IQI 31 : IN-HOSP MORT CAROTID ENDARTERECTMY--- ;
 * -------------------------------------------------- ;

   if MDC notin (14) and 
      %MPR($PRCEATP.) 
   then do;

      TPIQ31 = 0;
	  if DISP in (20) then TPIQ31 = 1;

   end;


 * --- CONSTRUCT PROVIDER LEVEL UTILIZATION INDICATORS ---------- ;

 * -------------------------------------------------- ;
 * --- IQI 21 : CESAREAN SECTION DELIVERY         --- ;
 * -------------------------------------------------- ;

   if %MDX($DELOCMD.)
   then do;

      TPIQ21 = 0;

      if %MDR($PRCSE2G.) or 
         (%MPR($PRCSECP.) and not %MPR($PRCSE2P.)) then

         TPIQ21 = 1;

      if %MDX($PRCSECD.) then

         TPIQ21 = .;

   end;

 * -------------------------------------------------- ;
 * --- IQI 22 : VAGINAL BIRTH AFTER C-SECTION     --- ;
 * -------------------------------------------------- ;

   if %MDX($DELOCMD.) and %MDX($PRVBACD.) 
   then do;

      TPIQ22 = 0;
      TPIQ34 = 0;

   if %MPR($VAGDELP.) then do;

         TPIQ22 = 1;
         TPIQ34 = 1;

      end;

      if %MDX($PRCSECD.) then

         TPIQ22 = .;

   end;

 * -------------------------------------------------- ;
 * --- IQI 23 : LAPAROSCOPIC CHOLECYSTECTOMY      --- ;
 * -------------------------------------------------- ;

   if MDC notin (14) and 
      %MPR($PRLAP2P.) and %MDX($PRLAPOD.) 
   then do;

      TPIQ23 = 0;

      if %MPR($PRLAPOP.) then

         TPIQ23 = 1;

   end;

 * -------------------------------------------------- ;
 * --- IQI 24 : INCIDENTAL APPENDECTOMY           --- ;
 * -------------------------------------------------- ;

   if MDC notin (14) and (AGE >=65 ) and 
     %MPR($PRAPP2P.) 
   then do;

      TPIQ24=0;

      if %MPR($PRAPPNP.) then

         TPIQ24 = 1;

      *** Exclude Colectomy or Pelvic Evisceration;

      if %MPR($PRAPP3P.) then

         TPIQ24 = .;

      *** Exclude Cancer adj to Appendix;

      if %MDX($PRAPPND.) then

         TPIQ24 = .;

   end;

 * -------------------------------------------------- ;
 * --- IQI 25 : BI-LATERAL CATHETERIZATION        --- ;
 * -------------------------------------------------- ;

   if MDC notin (14) and 
      %MPR($PRCAT2P.) and %MDX($PRCATHD.) 
   then do;

      TPIQ25 = 0;

      if %MPR($PRCATHP.) and not %MDX($PRCAT2D.) then

         TPIQ25 = 1;

   end;


 * --- CONSTRUCT AREA LEVEL UTILIZATION INDICATORS -------------- ;

 * -------------------------------------------------- ;
 * --- IQI 26 : CORONARY ARTERY BYPASS GRAFT      --- ;
 * -------------------------------------------------- ;

   if MDC notin (14) and (AGE >= 40) and
      %MPR($PRCABGP.) 
   then

      TAIQ26 = 1;

 * -------------------------------------------------- ;
 * --- IQI 27 : PTCA                              --- ;
 * -------------------------------------------------- ;

   if MDC notin (14) and (AGE >= 40) and 
      %MPR($PRPTCAP.) 
   then

      TAIQ27 = 1;

 * -------------------------------------------------- ;
 * --- IQI 28 : HYSTERECTOMY                      --- ;
 * -------------------------------------------------- ;

   if MDC notin (14) and (SEX=2) and
      %MPR($PRHYSTP.) 
   then do;

      TAIQ28 = 1;

      * --- EXCLUDE GENITAL CANCER -------------------- ;
      if %MDX($PRHYS1D.) then TAIQ28 = .;

      * --- EXCLUDE PELVIC OR LOWER ABDOMINAL --------- ;
      else if %MDX($PRHYS2D.) then TAIQ28 = .;

   end;

 * -------------------------------------------------- ;
 * --- IQI 29 : LAMINECTOMY AND/OR SPINAL FUSION  --- ;
 * -------------------------------------------------- ;

   if MDC notin (14) and
      %MPR($PRLAMIP.) 
   then

      TAIQ29 = 1;


 * --- CONSTRUCT ADDIT'L PROVIDER LEVEL UTILIZATION INDICATORS -- ;

   if TPIQ21 NE . and TPIQ22 EQ . then TPIQ33 = TPIQ21;

 * -------------------------------------------------------------- ;
 * --- EXCLUDE CASES WITH MISSING VALUES FOR DISP OR ASOURCE  --- ;
 * -------------------------------------------------------------- ;

 if (DISP lt 0) then do;
   TPIQ08  = .;
   TPIQ09  = .; 
   TPIQ09A = .;
   TPIQ09B = .;
   TPIQ11  = .;
   TPIQ11A = .;
   TPIQ11B = .;
   TPIQ11C = .;
   TPIQ11D = .;
   TPIQ12  = .;
   TPIQ13  = .;
   TPIQ14  = .;
   TPIQ15  = .;
   TPIQ16  = .;
   TPIQ17  = .;
   TPIQ17A = .;
   TPIQ17B = .;
   TPIQ17C = .;
   TPIQ18  = .;
   TPIQ19  = .;
   TPIQ20  = .;
   TPIQ30  = .;
   TPIQ31  = .;
   TPIQ32  = .;
 end;

 if (ASOURCE lt 0) and (POINTOFORIGINUB04 in (' ')) then 
   TPIQ32 = .;

 * -------------------------------------------------------------- ;
 * --- EXCLUDE TRANSFERS ---------------------------------------- ;
 * -------------------------------------------------------------- ;

 * --- TRANSFER FROM ANOTHER ACUTE ---------------- ;
 if ASOURCE in (2) or POINTOFORIGINUB04 in ('4') then do; 
   TPIQ32 = .;
 end;

 * --- TRANSFER TO ANOTHER ACUTE ------------------ ;
 if DISP in (2) then do;
   TPIQ08   = .;
   TPIQ09   = .;
   TPIQ09A  = .; 
   TPIQ09B  = .;
   TPIQ11   = .;
   TPIQ11A  = .; 
   TPIQ11B  = .;
   TPIQ11C  = .;
   TPIQ11D  = .;
   TPIQ12   = .;
   TPIQ13   = .;
   TPIQ14   = .;
   TPIQ15   = .;
   TPIQ16   = .;
   TPIQ17   = .;
   TPIQ17A  = .;
   TPIQ17B  = .;
   TPIQ17C  = .;
   TPIQ18   = .;
   TPIQ19   = .;
   TPIQ20   = .;
   TPIQ30   = .;
   TPIQ31   = .;
   TPIQ32   = .;
 end;

 * -------------------------------------------------------------- ;
 * --- IDENTIFY TRANSFERS --------------------------------------- ;
 * -------------------------------------------------------------- ;

 * --- TRANSFER FROM ANOTHER ACUTE ---------------- ;
 if ASOURCE in (2) OR POINTOFORIGINUB04 in ('4') then TRNSFER = 1;
 else TRNSFER = 0;
 if ASOURCE gt .Z and POINTOFORIGINUB04 in (' ') then NOPOUB04 = 1;
 else NOPOUB04 = 0;

 * --- TRANSFER TO ANOTHER ACUTE ---------------- ;
 if DISP in (2) then TRNSOUT = 1;else TRNSOUT = 0;

 * -------------------------------------------------------------- ;
 * --- LABELS --------------------------------------------------- ;
 * -------------------------------------------------------------- ;

 label
    TRNSFER  = 'TRANSFER FROM ACUTE'
    TRNSOUT  = 'TRANSFER TO ACUTE'
    MAXDX    = 'NUMBER OF DX CODES'
    MAXPR    = 'NUMBER OF PR CODES'
    NOPRDAY  = 'NO PRDAY'
    NOPOUB04 = 'NO POINT OF ORIGIN'
;

run;

proc MEANS data=OUTMSR.&OUTFILE_MEAS. N NMISS MIN MAX MEAN SUM;
title "INPATIENT QUALITY INDICATOR NUMERATOR (=SUM),DENOMINATOR (=N), AND OBSERVED RATE (MEAN) ";
run;

proc CONTENTS data=OUTMSR.&OUTFILE_MEAS. POSITION;
title "INPATIENT QUALITY INDICATOR MEASURE OUTPUT ";
run;

proc PRINT data=OUTMSR.&OUTFILE_MEAS.(OBS=24);
title4 "FIRST 24 RECORDS IN OUTPUT DATA SET &OUTFILE_MEAS.";
run;
