*=============== Program: IQI_AREA_OBSERVED.SAS  ================;
*
*       Title:  AREA OBSERVED RATES FOR AHRQ 
*               INPATIENT QUALITY INDICATORS
*  Description:
*         USES PROC SUMMARY TO CALCULATE POPULATION AND OBSERVED 
*         RATES FOR INPATIENT QUALITY INDICATORS ACROSS STRATIFIERS.
*         OUTPUT STRATIFIED BY AREA, AGECAT, SEXCAT AND RACECAT FROM 
*         POPULATION FILE AND IQI_ALL_MEASURE OUTPUT.
*         VARIABLES CREATED ARE PAIQxx and OAIQxx
*
*           >>> AHRQ QI ICD-10 VERSION 6.0.1 <<<
*		      >>> VERSION DATE SEPT, 2016 <<<
*===============================================================;

*PATHNAME specifies the location of the IQI folder which includes 
          Programs, SASdata, and Macros subfolders;
%LET PATHNAME= c:\Pathname;                *<===USER MUST modify; 
filename CONTROL "&PATHNAME.\IQI\Programs\IQI_ALL_CONTROL.SAS"; 

%include CONTROL;
/*MACRO TO ADJUST AREA AGGREGATION BASED ON MAREA VALUE IN IQI_ALL_CONTROL.*/

 %MACRO CTY2MA;
    %IF &MALEVL EQ 0 %THEN %DO;
        attrib MAREA length=$5
          label='FIPS STATE COUNTY CODE';
        MAREA = FIPSTCO;
    %END;
    %ELSE %IF &MALEVL EQ 1 %THEN %DO;
        attrib MAREA length=$5
          label='MODIFIED FIPS';
        MAREA = input(put(FIPSTCO,$M1AREA.),$5.);
    %END;
    %ELSE %IF &MALEVL EQ 2 %THEN %DO;
        attrib MAREA length=$5
          label='OMB 1999 METRO AREA';
        MAREA = input(put(FIPSTCO,$M2AREA.),$5.);
    %END;
    %ELSE %IF &MALEVL EQ 3 %THEN %DO;
        attrib MAREA length=$5
          label='OMB 2003 METRO AREA';
        MAREA = input(put(FIPSTCO,$M3AREA.),$5.);
    %END;
 %MEND;

 title2 'PROGRAM IQI_AREA_OBSERVED';
 title3 'AHRQ INPATIENT QUALITY INDICATORS: CALCULATE ADJUSTED AREA RATES';

 * ---------------------------------------------------------------- ;
 * --- ADD POPULATION DENOMINATOR                               --- ;
 * --- THIS STEP DETERMINES WHICH AREAS ARE INCLUDED IN THE     --- ;
 * --- OUTPUT BASED ON AREAS IN IQI_ALL_MEASURES.               --- ;
 * ---------------------------------------------------------------- ;

 data   TEMP0 (keep=MAREA);
 set    OUTMSR.&OUTFILE_MEAS.;

 %CTY2MA

 run;
/* IDENTIFY MAREA VALUES IN IQI_ALL_MEASURES OUTPUT. */
 proc   Sort data=TEMP0 out=MAREA nodupkey;
 by     MAREA;
 run;
/* LOAD POPULATION FOR MAREA LEVEL AND YEAR IN IQI_ALL_CONTROL. */
 data   QIPOP0;
    length FIPSTCO $5 SEXCAT POPCAT AGECAT RACECAT 3 
           POP_1995 POP_1996 POP_1997 POP_1998 POP_1999
           POP_2000 POP_2001 POP_2002 POP_2003 POP_2004
           POP_2005 POP_2006 POP_2007 POP_2008 POP_2009 
           POP_2010 POP_2011 POP_2012 POP_2013 POP_2014
           POP_2015 POP 8;

    infile POPFILE missover firstobs=2;

    input FIPSTCO SEXCAT POPCAT RACECAT 
          POP_1995 POP_1996 POP_1997 POP_1998 POP_1999
          POP_2000 POP_2001 POP_2002 POP_2003 POP_2004
          POP_2005 POP_2006 POP_2007 POP_2008 POP_2009
          POP_2010 POP_2011 POP_2012 POP_2013 POP_2014
		  POP_2015;

    %CTY2MA

    if POPCAT in (1,2,3,4)            then AGECAT = 0;
    else if POPCAT in (5,6,7,8)       then AGECAT = 1;
    else if POPCAT in (9,10,11,12,13) then AGECAT = 2;
    else if POPCAT in (14,15)         then AGECAT = 3;
    else                                   AGECAT = 4;

    POP = POP_&POPYEAR.;

 run;

 proc   Summary data=QIPOP0 nway;
 class MAREA POPCAT AGECAT SEXCAT RACECAT;
 var POP;
 output out=QIPOP sum=;
 run;

 proc   Sort data=QIPOP;
 by     MAREA POPCAT AGECAT SEXCAT RACECAT;
 run;
/* LIMIT POPULATION TOTALS TO MAREA CODES FOUND IN IQI_MEASURES OUTPUT. */
 data   QIPOP(keep=MAREA POPCAT AGECAT SEXCAT RACECAT POP);
 merge  MAREA(in=X) QIPOP(in=Y);
 by     MAREA;

 if X and Y;

 run;

* --------------------------------------------------------------- *
 * --- INPATIENT QUALITY INDICATOR ADJUSTED RATES --------------- *
 * -------------------------------------------------------------- *
 * AREA-LEVEL INDICATOR DENOMINATORS ARE ADJUSTED BASED ON THE    *
 * COMBINATION OF COUNTY, AGE, SEX, AND RACE IN THE NUMERATOR.    *
 * THE MOD3 MACRO ITERATES THROUGH EACH MEASURE IN THE            *
 * IQI_ALL_ MEASURES OUTPUT AND REDUCES THE POPULATION SUM BY THE *
 * NUMERATOR TOTAL. THE AREA POPULATION TOTAL IS ADJUSTED BASED   *
 * ON THE MEASURE RELAVENT POPULATION. ONLY VALID AREA CODES      *
 * ARE RETURNED. THE MOD3 INPUTS ARE:                             *
 * --- N - AREA MEASURE NUMBER                                --- *
 * --- IQ - THE INPATIENT QUALITY INDICATOR NAME WITHOUT THE  --- *
 * ---      PREFIX (A)                                        --- *
 * -------------------------------------------------------------- ;


%MACRO MOD3(N,IQ);

 /* CREATE TEMP TABLE WITH ALL DISCHARGES IN NUMERATOR FOR INDICATOR N. */ 

 data   TEMP_2;
 set    OUTMSR.&OUTFILE_MEAS.(keep=KEY FIPSTCO T&IQ. POPCAT AGECAT SEXCAT RACECAT);

 if T&IQ. in (1);

 %CTY2MA

 run;
/* SUM THE NUMERATOR 'T' FLAGS BY MAREA POPCAT AGECAT SEXCAT RACECAT. */
 proc   Summary data=TEMP_2 NWAY;
 class  MAREA POPCAT AGECAT SEXCAT RACECAT;
 var    T&IQ.;
 output out=TEMP_3 N=TCOUNT;
 run;

 proc   Sort data=TEMP_3;
 by     MAREA POPCAT AGECAT SEXCAT RACECAT;
 run;

 /* REDUCE THE DENOMINATOR POPULATION BY THE SUM OF THE NUMERATOR COUNT. */

 data   TEMP_4(drop=TCOUNT);
 merge  QIPOP(in=X keep=MAREA POPCAT AGECAT SEXCAT RACECAT POP) 
        TEMP_3(keep=MAREA POPCAT AGECAT SEXCAT RACECAT TCOUNT);
 by     MAREA POPCAT AGECAT SEXCAT RACECAT;

 if X;

 if TCOUNT > 0 then PCOUNT = POP - TCOUNT;
 else PCOUNT = POP;

 if PCOUNT < 0 then PCOUNT = 0;

 N = &N.;

 if N in (28) and SEXCAT in (1) then PCOUNT = 0;

 if AGECAT in (0) then PCOUNT = 0;

 if N in (26,27) and AGECAT in (1) then PCOUNT = 0;

 if PCOUNT = 0 then delete;

 run;

 /* FOR NUMERATOR, RETAIN ONLY RECORDS WITH A VALID MAREA CODE. */

 data   TEMP_3(drop=POP);
 merge  TEMP_3(in=X keep=MAREA POPCAT AGECAT SEXCAT RACECAT TCOUNT)
        QIPOP(keep=MAREA POPCAT AGECAT SEXCAT RACECAT POP);
 by     MAREA POPCAT AGECAT SEXCAT RACECAT;

 if X;

 if POP < 0 then PCOUNT = 0;
 else if TCOUNT > 0 then PCOUNT = TCOUNT;
 else PCOUNT = 0;

 if PCOUNT = 0 then delete;

 run;

 /* COMBINE THE NUMERATOR AND DENOMINATOR. */

 data   TEMP1;
 length FEMALE AGECAT1-AGECAT14 FAGECAT1-FAGECAT14 3;
 set    TEMP_3(in=X) TEMP_4;

 if X then T&IQ. = 1;
 else T&IQ. = 0;

 if SEXCAT in (2) then FEMALE = 1;
 else FEMALE = 0;

 array ARRY1{14} AGECAT1-AGECAT14;
 array ARRY2{14} FAGECAT1-FAGECAT14;

 do I = 1 TO 14;
    ARRY1(I) = 0; ARRY2(I) = 0;
 end;

 ARRY1(POPCAT-4) = 1;
 ARRY2(POPCAT-4) = FEMALE;

 run;

 data   TEMP1Y;
 set    TEMP1;
 ONE = 1;
 run;

 * ------------------------------------------------------------- ;
 * --- AGGREGATE POPULATION COUNTS BY STRATIFIERS            --- ;
 * ------------------------------------------------------------- ;

 proc   Summary data=TEMP1Y;
 class  MAREA AGECAT SEXCAT RACECAT;
 var    T&IQ. ONE;
 output out=ADJ_&IQ. SUM(T&IQ. ONE)=T&IQ. P&IQ.;
 weight   PCOUNT;
 run;

 data   ADJ_&IQ.(keep=MAREA AGECAT SEXCAT RACECAT T&IQ. P&IQ. _TYPE_);
 set    ADJ_&IQ.;

 if _TYPE_ &TYPELVLA;

 run;

 proc Sort data = ADJ_&IQ.;
 by MAREA AGECAT SEXCAT RACECAT;
 run;  quit;

proc   Datasets nolist;
 delete TEMP1 TEMP1Y TEMP_2 TEMP_3 TEMP_4;;
quit;

 %MEND;

 %MOD3(26,AIQ26);
 %MOD3(27,AIQ27);
 %MOD3(28,AIQ28);
 %MOD3(29,AIQ29);


/* MERGE THE ADJUSTED DENOMINATOR AND NUMERATOR FOR AREA INPATIENT QUALITY INDICATORS. */

 data TEMP2Y;
   merge ADJ_AIQ26 ADJ_AIQ27 ADJ_AIQ28 ADJ_AIQ29;
   by MAREA AGECAT SEXCAT RACECAT;
 run;
 
* ----------------------------------------------------------------- ;
* --- INPATIENT QUALITY INDICATOR (IQI) NAMING CONVENTION:      --- ;
* --- THE FIRST LETTER IDENTIFIES THE INPATIENT QUALITY         --- ;
* --- INDICATOR AS ONE OF THE FOLLOWING:
                (T) NUMERATOR ("TOP")
                (P) DENOMINATOR ("POPULATION")
                (O) OBSERVED RATES (T/P)
* --- THE SECOND LETTER IDENTIFIES THE INDICATOR AS AN AREA (A) --- ;
* --- LEVEL INDICATOR.  THE NEXT TWO CHARACTERS ARE ALWAYS      --- ;
* --- 'IQ'. THE LAST TWO DIGITS ARE THE INDICATOR NUMBER.       --- ;
* ----------------------------------------------------------------- ;
 

/* CALCULATE OBSERVED RATE AS SUM OF NUMERATOR / SUM OF ADJUSTED DENOMINATOR.*/
 data &OUTFILE_AREAOBS.;
 set TEMP2Y;

 array PIQ2{4} PAIQ26-PAIQ29 ;
 array TIQ{4}  TAIQ26-TAIQ29 ;
 array OIQ{4}  OAIQ26-OAIQ29 ;

 do J = 1 to 4;
    if TIQ{J} GT 0 and PIQ2{J} GT 0 then OIQ{J} = TIQ{J} / PIQ2{J};
    else if PIQ2{J} GT 0 then OIQ{J} = 0;
 end;

 label
 TAIQ26 = 'IQI 26 Coronary Artery Bypass Graft (CABG) Rate (Numerator)'
 TAIQ27 = 'IQI 27 Percutaneous Coronary Intervention (PCI) Rate (Numerator)'
 TAIQ28 = 'IQI 28 Hysterectomy Rate (Numerator)'
 TAIQ29 = 'IQI 29 Laminectomy or Spinal Fusion Rate (Numerator)'
 ;
 label
 PAIQ26 = 'IQI 26 Coronary Artery Bypass Graft (CABG) Rate (Denominator)'
 PAIQ27 = 'IQI 27 Percutaneous Coronary Intervention (PCI) Rate (Denominator)'
 PAIQ28 = 'IQI 28 Hysterectomy Rate (Denominator)'
 PAIQ29 = 'IQI 29 Laminectomy or Spinal Fusion Rate (Denominator)'
 ;
 label
 OAIQ26 = 'IQI 26 Coronary Artery Bypass Graft (CABG) Rate (Observed)'
 OAIQ27 = 'IQI 27 Percutaneous Coronary Intervention (PCI) Rate (Observed)'
 OAIQ28 = 'IQI 28 Hysterectomy Rate (Observed)'
 OAIQ29 = 'IQI 29 Laminectomy or Spinal Fusion Rate (Observed)'
 _TYPE_ = 'STRATIFICATION LEVEL                    '
 ;

 drop J;

 run;

proc Sort data=&OUTFILE_AREAOBS. out=OUTAOBS.&OUTFILE_AREAOBS.;
 by MAREA AGECAT SEXCAT RACECAT;
 run;

 * ------------------------------------------------------- ;
 * --- CONTENTS AND MEANS OF AREA OBSERVED OUTPUT FILE --- ;
 * ------------------------------------------------------- ;

 proc Contents data=OUTAOBS.&OUTFILE_AREAOBS. position;
 run;

 ***----- TO PRINT VARIABLE LABLES COMMENT OUT OR DELETE "NOLABELS" FROM PROC MEANS STATEMENTS -------***;

proc Means data=OUTAOBS.&OUTFILE_AREAOBS. (where=(_TYPE_ in (8))) n nmiss min max sum nolabels;
   var TAIQ26-TAIQ29 ;
   title  'SUMMARY OF AREA-LEVEL INPATIENT QUALITY INDICATOR NUMERATOR BY AREA (_TYPE_=8)';
run; quit;

 proc Means data=OUTAOBS.&OUTFILE_AREAOBS. (where=(_TYPE_ in (8))) n nmiss min max sum nolabels;
   var PAIQ26-PAIQ29 ;
   title  'SUMMARY OF AREA-LEVEL INPATIENT QUALITY INDICATOR DENOMINATOR BY AREA (_TYPE_=8)';
run; quit;

proc Means data=OUTAOBS.&OUTFILE_AREAOBS. (where=(_TYPE_ in (8))) n nmiss min max mean nolabels;
   var OAIQ26-OAIQ29 ;
   title  'SUMMARY OF AREA-LEVEL INPATIENT QUALITY OBSERVED INDICATOR RATES(MEAN) BY AREA (_TYPE_=8)';
run; quit;

 * -------------------------------------------------------------- ;
 * --- PRINT AREA OBSERVED MEANS FILE --------------------------- ;
 * -------------------------------------------------------------- ;

 %MACRO PRT2;

 %IF &PRINT. = 1 %THEN %DO;

 %MACRO PRT(IQ,TEXT);

 proc  PRINT data=OUTAOBS.&OUTFILE_AREAOBS. label SPLIT='*';
 var   MAREA AGECAT SEXCAT RACECAT TAIQ&IQ. PAIQ&IQ. OAIQ&IQ. ;
 label MAREA   = "MAREA"
       AGECAT  = "AGECAT"
       SEXCAT  = "SEXCAT"
       RACECAT = "RACECAT"
       TAIQ&IQ.   = "TAIQ&IQ.*(Numerator)"
       PAIQ&IQ.   = "PAIQ&IQ.*(Denominator)"
       OAIQ&IQ.   = "OAIQ&IQ.*(Observed)"
       ;
 format AGECAT AGECAT.   
        SEXCAT SEXCAT.
        RACECAT RACECAT.
        TAIQ&IQ. PAIQ&IQ. COMMA13.0
        OAIQ&IQ. 8.6
        ;
 title4 "Indicator &IQ.: &TEXT";
 run;

 %MEND PRT;

 %PRT(26,Coronary Artery Bypass Graft (CABG) Rate);
 %PRT(27,Percutaneous Coronary Intervention (PCI) Rate);
 %PRT(28,Hysterectomy Rate);
 %PRT(29,Laminectomy or Spinal Fusion Rate);

 %END;

 %MEND PRT2;

 %PRT2; 

 * -------------------------------------------------------------- ;
 * --- WRITE SAS OUTPUT DATA SET TO COMMA-DELIMITED TEXT FILE --- ;
 * --- FOR EXPORT INTO SPREADSHEETS                           --- ;
 * -------------------------------------------------------------- ;

 %MACRO TEXT;

 %IF &TXTAOBS. = 1  %THEN %DO;
	%LET TYPEARN  = %sysfunc(tranwrd(&TYPELVLA.,%str(,),_));
	%LET TYPEARN2  = %sysfunc(compress(&TYPEARN.,'(IN )'));
	%let IQCSVREF = %sysfunc(pathname(IQTXTAOB));
	%let IQCSVRF2 =  %sysfunc(tranwrd(&IQCSVREF.,.,_&TYPEARN2..));
	 data _NULL_;
 set OUTAOBS.&OUTFILE_AREAOBS.;
 file  "&IQCSVRF2." lrecl=2000 dsd;
 if _N_=1 then do;

  put "MAREA"  "," "Age"  "," "Sex"  "," "Race"  "," "Type" ","
 "TAIQ26" "," "TAIQ27" "," "TAIQ28" "," "TAIQ29" ","
 "PAIQ26" "," "PAIQ27" "," "PAIQ28" "," "PAIQ29" ","
 "OAIQ26" "," "OAIQ27" "," "OAIQ28" "," "OAIQ29";

 end;
 
 put MAREA $5. "," AGECAT 3. "," SEXCAT 3. "," RACECAT 3.  "," _TYPE_ 2.  ","
 (TAIQ26-TAIQ29) (7.0 ",")
  ","
 (PAIQ26-PAIQ29) (13.2 ",")
 ","
 (OAIQ26-OAIQ29) (12.10 ",")
 ;
 run;

 %END;

 %MEND TEXT;

 %TEXT;
