*=================== Program: PQI09_ALL_MEASURES.SAS ===========================;
*
*  Description:
*         Assigns the Prevention Quality Indicator 09, Low Birth Weight Rate
		  to inpatient records. 
*
*                >>> AHRQ QI ICD-10 VERSION 6.0.1 <<<
*		           >>> VERSION DATE SEPT, 2016 <<<
*
*  USER NOTE1: The PQI09_ALL_FORMATS.SAS program must be run BEFORE
*               running this program.

*  USER NOTE2: The AHRQ QI software does not support the calculation of  
*              weighted estimates and standard errors using complex 
*              sampling designs. 
* ============================================================================;
*PATHNAME specifies the location of the PQI09 folder which includes 
          Programs, SASdata, and Macros subfolders;
%LET PATHNAME=c:\pathname;                        *<==USER MUST modify;

filename CONTROL "&PATHNAME.\PQI09\Programs\PQI09_ALL_CONTROL.SAS"; 

%INCLUDE CONTROL;

 title2 'PQI 09 MEASURE PROGRAM';
 title3 'AHRQ PREVENTION QUALITY INDICATORS: ASSIGN PQI 09 TO INPATIENT DATA';

 * -------------------------------------------------------------- ;
 * --- CREATE A PERMANENT DATASET CONTAINING ALL RECORDS THAT --- ; 
 * --- WILL NOT BE INCLUDED IN ANALYSIS BECAUSE KEY VARIABLE  --- ;
 * --- VALUES ARE MISSING.                                    --- ;
 * -------------------------------------------------------------- ;

 data   OUTMSR.&DELFILE.
 	(keep=KEY HOSPID SEX AGE DX1 MDC YEAR DQTR);
 set INMSR.&DISCHARGE.;
 if (AGE lt 0) or (AGE ge 18 or MDC IN (14)) or (SEX le 0) or 
	(DX1 IN (' ')) or (DQTR le .Z) or (YEAR le .Z);
 run;

  *--- LOAD STANDARD DIAGNOSIS AND PROCEDURE CODE MACROS ---* ;
 %include Maclib(PQI09_Dx_Px_Macros.sas) ;

 * ---------------------------------------------------------------- ;
 * --- PREVENTION QUALITY INDICATOR (PQI) NAMING CONVENTION:    --- ;
 * --- THE FIRST LETTER IDENTIFIES THE PREVENTION INDICATOR     --- ;
 * --- AS NUMERATOR, 'T' ("TOP").                               --- ;
 * --- THE SECOND LETTER IDENTIFIES THE TYPE OF INDICATOR WITH  --- ;
 * ---  'A' FOR AREA LEVEL.                                     --- ;
 * --- THE NEXT TWO CHARACTERS ARE 'PQ'. THE LAST TWO DIGITS    --- ;
 * ---  ARE 09 FOR INDICATOR PQI 09.                            --- ;
 * ---------------------------------------------------------------- ;

 DATA   OUTMSR.&OUTFILE_MEAS. 
    (KEEP=KEY HOSPID FIPST FIPSTCO DRG MDC MDRG YEAR DQTR 
          PAGECAT AGEDCAT POPCAT BWHTCAT SEXCAT RACECAT PAYCAT DUALCAT
          LOS TRNSFER NOPOUB04 TRNSOUT TAPQ09);
 SET   INMSR.&DISCHARGE. 
      (KEEP=KEY HOSPID DRG MDC SEX AGE AGEDAY PSTCO 
            RACE YEAR DQTR PAY1 PAY2 DNR
            DISP LOS ASOURCE POINTOFORIGINUB04 ATYPE
            DX1-DX&NDX. DXPOA1-DXPOA&NDX.);


 * -------------------------------------------------------------- ;
 * --- DEFINE MDC                        ------------------------ ;
 * -------------------------------------------------------------- ;
 attrib MDCNEW length=3
   label='IMPUTED MDC';

 if MDC NOTIN (01,02,03,04,05,06,07,08,09,10,
               11,12,13,14,15,16,17,18,19,20,
               21,22,23,24,25)
 then do;
    MDCNEW = put(DRG,MDCF2T.);
    if MDCNEW IN (01,02,03,04,05,06,07,08,09,10,
                  11,12,13,14,15,16,17,18,19,20,
                  21,22,23,24,25)
    then MDC=MDCNEW;
    else do;
       if DRG IN (999) then MDC = 0;
       else put "INVALID MDC KEY: " KEY " MDC " MDC " DRG " DRG ;
    end;
 end;
 

 * -------------------------------------------------------------- ;
 * --- DELETE NON-PEDIATRIC RECORDS and RECORDS W MISSING VALUES  ;
 * -------------------------------------------------------------- ;
 if SEX le 0 then delete;
 if AGE lt 0 then delete;
 if AGE ge 18 or MDC IN (14) then delete;
 if DX1 IN (' ') then delete;
 if DQTR le .Z then delete;
 if YEAR le .Z then delete;

 * -------------------------------------------------------------- ;
 * --- DEFINE FIPS STATE and COUNTY CODES             ----------- ;
 * -------------------------------------------------------------- ;
 attrib FIPSTCO length=$5
   label='FIPS STATE COUNTY CODE';
 FIPSTCO = put(PSTCO,Z5.);

 attrib FIPST length=$2
   label='STATE FIPS CODE';
 FIPST = SUBSTR(FIPSTCO,1,2);


 * -------------------------------------------------------------- ;
 * --- DEFINE ICD-10-CM VERSION          ------------------------ ;
 * -------------------------------------------------------------- ;
 attrib ICDVER length=3
   label='ICD-10-CM VERSION';

 ICDVER = 0;
 if (YEAR in (2015) and DQTR in (4))     then ICDVER = 33;
 else if (YEAR in (2016) and DQTR in (1,2,3)) then ICDVER = 33;
 else ICDVER=33;
 

 * -------------------------------------------------------------- ;
 * --- DEFINE MODIFIED DRGS              ------------------------ ;
 * -------------------------------------------------------------- ;
 attrib MDRG length=3
   label='MODIFIED DRG';

 MDRG = put(put(DRG,Z3.),$DRGF2T.);


 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: PAYER CATEGORY ------------------------ ;
 * -------------------------------------------------------------- ;
 attrib PAYCAT length=3
   label='PATIENT PRIMARY PAYER';

 select (PAY1);
   when (1)  PAYCAT = 1;
   when (2)  PAYCAT = 2;
   when (3)  PAYCAT = 3;
   when (4)  PAYCAT = 4;
   when (5)  PAYCAT = 5;
   otherwise PAYCAT = 6;
 end; * select PAY1 ;

 attrib DUALCAT length=3
   label='PATIENT DUAL ELIGIBLE';

 if (PAY1 IN (1) and PAY2 IN (2)) or
    (PAY1 IN (2) and PAY2 IN (1)) 
 then DUALCAT = 1; else DUALCAT = 0;
    

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: RACE CATEGORY ------------------------- ;
 * -------------------------------------------------------------- ;
 attrib RACECAT length=3
   label='PATIENT RACE/ETHNICITY';

 select (RACE);
   when (1)  RACECAT = 1;
   when (2)  RACECAT = 2;
   when (3)  RACECAT = 3;
   when (4)  RACECAT = 4;
   when (5)  RACECAT = 5;
   otherwise RACECAT = 6;
 end; * select RACE ;


 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: AGE CATEGORY  ------------------------- ;
 * -------------------------------------------------------------- ;
 attrib PAGECAT length=3
   label='PATIENT AGE';

 select;
   when (0  <= AGE <  1)  PAGECAT = 1;
   when (1  <= AGE <  3)  PAGECAT = 2;
   when (3  <= AGE <  6)  PAGECAT = 3;
   when (6  <= AGE < 13)  PAGECAT = 4;
   when (13 <= AGE < 18)  PAGECAT = 5;
   otherwise PAGECAT = 0;
 end; * select AGE ;


 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: AGEDAY CATEGORY  ---------------------- ;
 * -------------------------------------------------------------- ;
 attrib AGEDCAT length=3
   label='PATIENT AGE IN DAYS';

 select;
   when (      AGEDAY <   0)  AGEDCAT = 0;
   when (0  <= AGEDAY <= 28)  AGEDCAT = 1;
   when (29 <= AGEDAY <= 60)  AGEDCAT = 2;
   when (61 <= AGEDAY <= 90)  AGEDCAT = 3;
   when (91 <= AGEDAY      )  AGEDCAT = 4;
   otherwise AGEDCAT = 0;
 end; * select AGEDAY ;


 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: SEX CATEGORY  ------------------------- ;
 * -------------------------------------------------------------- ;
 attrib SEXCAT length=3
   label='PATIENT SEX';

 select (SEX);
   when (1)  SEXCAT = 1;
   when (2)  SEXCAT = 2;
   otherwise SEXCAT = 0;
 end; * select SEX ;


 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: POPULATION CATEGORY ------------------- ;
 * -------------------------------------------------------------- ;
 attrib POPCAT length=3
   label='PATIENT AGE';

 POPCAT=put(AGE,AGEFMT.);


 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: BIRTH WEIGHT CATEGORY  ---------------- ;
 * -------------------------------------------------------------- ;
 attrib BWHTCAT length=3
   label='PATIENT BIRTHWEIGHT';

 %MACRO BWHT;

 BWHTCAT = 0;
 %DO I = 1 %TO &NDX.;
    if put(DX&I.,$LW500G.)  = '1'      then BWHTCAT = 1;
    else if put(DX&I.,$LW750G.)  = '1' and (BWHTCAT = 0 or  BWHTCAT > 2) then BWHTCAT = 2;
    else if put(DX&I.,$LW1000G.) = '1' and (BWHTCAT = 0 or  BWHTCAT > 3) then BWHTCAT = 3;
    else if put(DX&I.,$LW1250G.) = '1' and (BWHTCAT = 0 or  BWHTCAT > 4) then BWHTCAT = 4;
    else if put(DX&I.,$LW1500G.) = '1' and (BWHTCAT = 0 or  BWHTCAT > 5) then BWHTCAT = 5;
    else if put(DX&I.,$LW1750G.) = '1' and (BWHTCAT = 0 or  BWHTCAT > 6) then BWHTCAT = 6;
    else if put(DX&I.,$LW2000G.) = '1' and (BWHTCAT = 0 or  BWHTCAT > 7) then BWHTCAT = 7;
    else if put(DX&I.,$LW2500G.) = '1' and (BWHTCAT = 0 or  BWHTCAT > 8) then BWHTCAT = 8;
 %END;
 
 %MEND;

 %BWHT;


 * -------------------------------------------------------------- ;
 * --- DEFINE AREA LEVEL INDICATORS ----------------------------- ;
 * -------------------------------------------------------------- ;
%MACRO LBL;

 attrib
 TAPQ09 length=8
   label='PQI 09 Low Birth Weight Rate (Numerator)'
;

%MEND;

%LBL;

 
 * -------------------------------------------------------------- ;
 * --- IDENTIFY NEONATES AND NEWBORNS --------------------------- ;
 * -------------------------------------------------------------- ;

   NEONATE = 0;
   if 0 <= AGEDAY <= 28 then NEONATE = 1;
   else if AGEDAY le .Z and AGE = 0 then do;
      if ATYPE IN (4) or  %MDX($LIVEBND.)
      then NEONATE = 1;
   end;

   NEWBORN = 0;
   if NEONATE then do;
      if %MDX($LIVEBND.) and NOT AGEDAY > 0 then NEWBORN = 1;
      else if ATYPE IN (4) and 
              ((AGEDAY = 0 and NOT %MDX($LIVEB2D.)) or
               POINTOFORIGINUB04 IN ('5'))
      then NEWBORN = 1;
   end;
 
   NORMAL = 0;
   if NEWBORN and (DRG IN (795))
   then NORMAL = 1;

   OUTBORN = 0;
   if NEONATE and NOT NEWBORN then do;
      if (0 <= AGEDAY < 2) or 
         (ATYPE IN (4) and 
          (AGEDAY le .Z or POINTOFORIGINUB04 IN ('6'))) 
      then OUTBORN = 1;
   end;


   * --- CONSTRUCT AREA LEVEL INDICATORS --- ;

   * -------------------------------------------------- ;
   * --- PQI 09 : LOW BIRTH WEIGHT                  --- ;
   * -------------------------------------------------- ;


   if NEWBORN then do;

      TAPQ09 = 0;

      if %MDX($ACSLBWD.) then TAPQ09 = 1;

   end;


 * -------------------------------------------------------------- ;
 * --- IDENTIFY TRANSFERS --------------------------------------- ;
 * -------------------------------------------------------------- ;

 * --- TRANSFER FROM ANOTHER ACUTE ---------------- ;
 if ATYPE notin (4) and
    (ASOURCE in (2) or POINTOFORIGINUB04 in ('4'))
 then TRNSFER = 1;
 else TRNSFER = 0;
 if ASOURCE GT .Z and POINTOFORIGINUB04 in (' ') then NOPOUB04 = 1;
 else NOPOUB04 = 0;

 * --- TRANSFER TO ANOTHER ACUTE ---------------- ;

 if DISP in (2) then TRNSOUT = 1;else TRNSOUT = 0;

 * -------------------------------------------------------------- ;
 * --- EXCLUDE TRANSFERS ---------------------------------------- ;
 * -------------------------------------------------------------- ;

 * --- TRANSFER FROM ANOTHER ---------------- ;
 if ATYPE notin (4) and
    (ASOURCE in (2,3) or POINTOFORIGINUB04 in ('4','5','6')) 
 then do;
   TAPQ09 = .;
 end;

 * -------------------------------------------------------------- ;
 * --- LABELS --------------------------------------------------- ;
 * -------------------------------------------------------------- ;

 label
    TRNSFER  = 'TRANSFER FROM ACUTE'
    TRNSOUT  = 'TRANSFER TO ACUTE'
    NOPOUB04 = 'NO POINT OF ORIGIN'
 ;

run;


proc Contents data=OUTMSR.&OUTFILE_MEAS. position;
run;

proc Print data=OUTMSR.&OUTFILE_MEAS. (OBS=24);
title4 "FIRST 24 RECORDS IN OUTPUT DATA SET &OUTFILE_MEAS.";
run;



***----- TO PRINT VARIABLE LABELS COMMENT (DELETE) "NOLABELS" FROM PROC MEANS STATEMENTS -------***;

proc Means data = OUTMSR.&OUTFILE_MEAS.  n nmiss min max nolabels ;
	 var KEY HOSPID DRG MDRG MDC YEAR DQTR 
         PAGECAT AGEDCAT POPCAT BWHTCAT SEXCAT RACECAT PAYCAT DUALCAT 
         LOS TRNSFER NOPOUB04 TRNSOUT;
     title4 "CATEGORICAL VARIABLES AND RANGES OF VALUES";
run; quit;

proc Means data = OUTMSR.&OUTFILE_MEAS. n nmiss sum mean  nolabels  ;
     var TAPQ09;
    * OUTPUT OUT=STATS;
     title "PREVENTION QUALITY INDICATOR NUMERATORS (COUNT =SUM)";
run; quit; 


